#include "sbsessionpool.h"

SB_PHP_METHOD(TSBSessionContext, __construct)
{
	if (ZEND_NUM_ARGS() == 0)
	{
		php_sbb_struct * intern = (php_sbb_struct *)zend_object_store_get_object(getThis() TSRMLS_CC);
		intern->data = emalloc(sizeof(TSBSessionContext));
		intern->len = sizeof(TSBSessionContext);
		intern->ownData = 1;
	}
	else
		ZEND_WRONG_PARAM_COUNT();
}

SB_PHP_METHOD(TSBSessionContext, getSizeOf)
{
	if (ZEND_NUM_ARGS() > 0)
		ZEND_WRONG_PARAM_COUNT();

	RETURN_LONG(sizeof(TSBSessionContext));
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TSBBaseStruct_GetField, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TSBBaseStruct_SetField, 0, 0, 1)
	ZEND_ARG_INFO(0, value)
ZEND_END_ARG_INFO()

SB_PHP_METHOD(TSBSessionContext, get_Version)
{
	SBStuctGetFieldInt32(INTERNAL_FUNCTION_PARAM_PASSTHRU, 8);
}

SB_PHP_METHOD(TSBSessionContext, set_Version)
{
	SBStuctSetFieldInt32(INTERNAL_FUNCTION_PARAM_PASSTHRU, 8);
}

SB_PHP_METHOD(TSBSessionContext, get_StartTime)
{
	SBStuctGetFieldUInt32(INTERNAL_FUNCTION_PARAM_PASSTHRU, 12);
}

SB_PHP_METHOD(TSBSessionContext, set_StartTime)
{
	SBStuctSetFieldUInt32(INTERNAL_FUNCTION_PARAM_PASSTHRU, 12);
}

zend_class_entry *TSBSessionContext_ce_ptr = NULL;

static zend_function_entry TSBSessionContext_methods[] = {
	PHP_ME(TSBSessionContext, __construct, NULL, ZEND_ACC_PUBLIC)
	PHP_ME(TSBSessionContext, getSizeOf, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
	PHP_ME(TSBSessionContext, get_Version, arginfo_TSBBaseStruct_GetField, ZEND_ACC_PUBLIC)
	PHP_ME(TSBSessionContext, set_Version, arginfo_TSBBaseStruct_SetField, ZEND_ACC_PUBLIC)
	PHP_ME(TSBSessionContext, get_StartTime, arginfo_TSBBaseStruct_GetField, ZEND_ACC_PUBLIC)
	PHP_ME(TSBSessionContext, set_StartTime, arginfo_TSBBaseStruct_SetField, ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TSBSessionContext(TSRMLS_D)
{
	zend_class_entry ce;
	if (TSBSessionContext_ce_ptr != NULL)
		return;
	INIT_CLASS_ENTRY(ce, "TSBSessionContext", TSBSessionContext_methods);
	TSBSessionContext_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseStruct_ce_ptr, NULL TSRMLS_CC);
}

void SB_CALLBACK TSBSessionCreatedEventRaw(void * _ObjectData, TObjectHandle Sender, TObjectHandle Server, const uint8_t pSessionID[], int32_t szSessionID, TObjectHandle * SessionInfo, int8_t * FreeOnRelease)
{
	zval *retval_ptr;
	zval **params[5];
	zval * zSender;
	zval * zServer;
	zval * zSessionID;
	zval * zSessionInfo;
	zval * zFreeOnRelease;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zServer);
	SBInitObject(zServer, TObject_ce_ptr, Server TSRMLS_CC);
	MAKE_STD_ZVAL(zSessionID);
	ZVAL_STRINGL(zSessionID, pSessionID, szSessionID, 1);
	MAKE_STD_ZVAL(zSessionInfo);
	SBInitObject(zSessionInfo, TObject_ce_ptr, *SessionInfo TSRMLS_CC);
	MAKE_STD_ZVAL(zFreeOnRelease);
	ZVAL_BOOL(zFreeOnRelease, (zend_bool)*FreeOnRelease);

	params[0] = &zSender;
	params[1] = &zServer;
	params[2] = &zSessionID;
	params[3] = &zSessionInfo;
	params[4] = &zFreeOnRelease;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 5, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zServer);
	zval_ptr_dtor(&zSessionID);
	*SessionInfo = SBGetObjectHandleCE(zSessionInfo, TObject_ce_ptr TSRMLS_CC);
	SBDetachObjectHandleIfUniqueZVal(zSessionInfo TSRMLS_CC);
	zval_ptr_dtor(&zSessionInfo);
	*FreeOnRelease = (int8_t)Z_BVAL_P(zFreeOnRelease);
	zval_ptr_dtor(&zFreeOnRelease);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

void SB_CALLBACK TSBSessionReleasedEventRaw(void * _ObjectData, TObjectHandle Sender, const uint8_t pSessionID[], int32_t szSessionID, TObjectHandle SessionInfo)
{
	zval *retval_ptr;
	zval **params[3];
	zval * zSender;
	zval * zSessionID;
	zval * zSessionInfo;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zSender);
	SBInitObject(zSender, TObject_ce_ptr, Sender TSRMLS_CC);
	MAKE_STD_ZVAL(zSessionID);
	ZVAL_STRINGL(zSessionID, pSessionID, szSessionID, 1);
	MAKE_STD_ZVAL(zSessionInfo);
	SBInitObject(zSessionInfo, TObject_ce_ptr, SessionInfo TSRMLS_CC);

	params[0] = &zSender;
	params[1] = &zSessionID;
	params[2] = &zSessionInfo;
	SBCallEvent((zval *)_ObjectData, &retval_ptr, 3, params TSRMLS_CC);

	zval_ptr_dtor(&zSender);
	zval_ptr_dtor(&zSessionID);
	zval_ptr_dtor(&zSessionInfo);
	if (retval_ptr) zval_ptr_dtor(&retval_ptr);
}

zend_class_entry *TElSessionPool_ce_ptr = NULL;

SB_PHP_METHOD(TElSessionPool, Add)
{
	long l4Version;
	SBArrayZValInfo aiMasterKey;
	SBArrayZValInfo aiSessionID;
	zend_bool bAuthDone;
	zend_bool bFreeOnRelease;
	zval *oServer;
	zval *oSessInfo;
	zval *zaMasterKey;
	zval *zaSessionID;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!lzzbO!b", &oServer, TObject_ce_ptr, &l4Version, &zaMasterKey, &zaSessionID, &bAuthDone, &oSessInfo, TObject_ce_ptr, &bFreeOnRelease) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaMasterKey)) || (IS_ARRAY == Z_TYPE_P(zaMasterKey)) || (IS_NULL == Z_TYPE_P(zaMasterKey))) && ((IS_STRING == Z_TYPE_P(zaSessionID)) || (IS_ARRAY == Z_TYPE_P(zaSessionID)) || (IS_NULL == Z_TYPE_P(zaSessionID))))
	{
		if (!SBGetByteArrayFromZVal(zaMasterKey, &aiMasterKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaSessionID, &aiSessionID TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElSessionPool_Add(SBGetObjectHandle(getThis() TSRMLS_CC), SBGetObjectHandle(oServer TSRMLS_CC), (int32_t)l4Version, aiMasterKey.data, aiMasterKey.len, aiSessionID.data, aiSessionID.len, (int8_t)bAuthDone, SBGetObjectHandle(oSessInfo TSRMLS_CC), (int8_t)bFreeOnRelease) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiMasterKey);
		SBFreeArrayZValInfo(&aiSessionID);
	}
	else
	{
		SBErrorExpectsArguments("(TObject, integer, array of byte|string|NULL, array of byte|string|NULL, bool, TObject, bool)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, Remove)
{
	SBArrayZValInfo aiSessionID;
	zval *zaSessionID;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zaSessionID) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaSessionID)) || (IS_ARRAY == Z_TYPE_P(zaSessionID)) || (IS_NULL == Z_TYPE_P(zaSessionID))))
	{
		if (!SBGetByteArrayFromZVal(zaSessionID, &aiSessionID TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElSessionPool_Remove(SBGetObjectHandle(getThis() TSRMLS_CC), aiSessionID.data, aiSessionID.len) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiSessionID);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, GetContext)
{
	SBArrayZValInfo aiSessionID;
	zval *zaSessionID;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zaSessionID) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaSessionID)) || (IS_ARRAY == Z_TYPE_P(zaSessionID)) || (IS_NULL == Z_TYPE_P(zaSessionID))))
	{
		TSBSessionContext * proOutResult;
		if (!SBGetByteArrayFromZVal(zaSessionID, &aiSessionID TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(TElSessionPool_GetContext(SBGetObjectHandle(getThis() TSRMLS_CC), aiSessionID.data, aiSessionID.len, &proOutResult) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiSessionID);
		object_init_ex(return_value, TSBSessionContext_ce_ptr);
		SBSetStructPointer(return_value, proOutResult, sizeof(TSBSessionContext) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_Timeout)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElSessionPool_get_Timeout(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, set_Timeout)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElSessionPool_set_Timeout(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_Interval)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElSessionPool_get_Interval(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, set_Interval)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElSessionPool_set_Interval(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_MaxCount)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(TElSessionPool_get_MaxCount(SBGetObjectHandle(getThis() TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, set_MaxCount)
{
	long l4Value;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "l", &l4Value) == SUCCESS)
	{
		SBCheckError(TElSessionPool_set_MaxCount(SBGetObjectHandle(getThis() TSRMLS_CC), (int32_t)l4Value) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_StatelessSymmetricKey)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		_err = TElSessionPool_get_StatelessSymmetricKey(SBGetObjectHandle(getThis() TSRMLS_CC), u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(-967800637, 1, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_StatelessHMACKey)
{
	uint32_t _err;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		_err = TElSessionPool_get_StatelessHMACKey(SBGetObjectHandle(getThis() TSRMLS_CC), u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(1020709448, 1, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_OnSessionCreated)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBSessionCreatedEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElSessionPool_get_OnSessionCreated(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, set_OnSessionCreated)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElSessionPool_set_OnSessionCreated(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBSessionCreatedEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBSessionCreatedEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, get_OnSessionReleased)
{
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS)
	{
		TSBSessionReleasedEvent pMethodOutResult = NULL;
		void * pDataOutResult = NULL;
		SBCheckError(TElSessionPool_get_OnSessionReleased(SBGetObjectHandle(getThis() TSRMLS_CC), &pMethodOutResult, &pDataOutResult) TSRMLS_CC);
		if (NULL != pDataOutResult)
		{
			INIT_PZVAL_COPY(return_value, (zval *)pDataOutResult);
			zval_copy_ctor(return_value);
		}
		else
			ZVAL_NULL(return_value);
	}
	else
	{
		SBErrorExpectsArguments("()" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, set_OnSessionReleased)
{
	void *pzValue;
	zval *zValue;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "z", &zValue) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zValue)) || (IS_ARRAY == Z_TYPE_P(zValue)) || (IS_CALLABLE == Z_TYPE_P(zValue)) || (IS_NULL == Z_TYPE_P(zValue))))
	{
		pzValue = SBSetEventData(zValue TSRMLS_CC);
		SBCheckError(TElSessionPool_set_OnSessionReleased(SBGetObjectHandle(getThis() TSRMLS_CC), pzValue ? &TSBSessionReleasedEventRaw : NULL, pzValue) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBSessionReleasedEvent|callable|NULL)" TSRMLS_CC);
	}
}

SB_PHP_METHOD(TElSessionPool, __construct)
{
	zval *oOwner;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oOwner, TComponent_ce_ptr) == SUCCESS)
	{
		TElClassHandle hoOutResult = NULL;
		SBCheckError(TElSessionPool_Create(SBGetObjectHandle(oOwner TSRMLS_CC), &hoOutResult) TSRMLS_CC);
		SBSetObjectHandle(getThis(), hoOutResult, ohTrue TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TComponent)" TSRMLS_CC);
	}
}

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_Add, 0, 0, 7)
	ZEND_ARG_OBJ_INFO(0, Server, TObject, 1)
	ZEND_ARG_INFO(0, Version)
	ZEND_ARG_TYPE_INFO(0, MasterKey, 0, 1)
	ZEND_ARG_TYPE_INFO(0, SessionID, 0, 1)
	ZEND_ARG_INFO(0, AuthDone)
	ZEND_ARG_OBJ_INFO(0, SessInfo, TObject, 1)
	ZEND_ARG_INFO(0, FreeOnRelease)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_Remove, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, SessionID, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_GetContext, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, SessionID, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_Timeout, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_set_Timeout, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_Interval, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_set_Interval, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_MaxCount, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_set_MaxCount, 0, 0, 1)
	ZEND_ARG_INFO(0, Value)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_StatelessSymmetricKey, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_StatelessHMACKey, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_OnSessionCreated, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_set_OnSessionCreated, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_get_OnSessionReleased, 0, 0, 0)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool_set_OnSessionReleased, 0, 0, 1)
	ZEND_ARG_TYPE_INFO(0, Value, 0, 1)
ZEND_END_ARG_INFO()

ZEND_BEGIN_ARG_INFO_EX(arginfo_TElSessionPool___construct, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, Owner, TComponent, 1)
ZEND_END_ARG_INFO()

static zend_function_entry TElSessionPool_methods[] = {
	PHP_ME(TElSessionPool, Add, arginfo_TElSessionPool_Add, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, Remove, arginfo_TElSessionPool_Remove, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, GetContext, arginfo_TElSessionPool_GetContext, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_Timeout, arginfo_TElSessionPool_get_Timeout, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, set_Timeout, arginfo_TElSessionPool_set_Timeout, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_Interval, arginfo_TElSessionPool_get_Interval, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, set_Interval, arginfo_TElSessionPool_set_Interval, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_MaxCount, arginfo_TElSessionPool_get_MaxCount, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, set_MaxCount, arginfo_TElSessionPool_set_MaxCount, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_StatelessSymmetricKey, arginfo_TElSessionPool_get_StatelessSymmetricKey, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_StatelessHMACKey, arginfo_TElSessionPool_get_StatelessHMACKey, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_OnSessionCreated, arginfo_TElSessionPool_get_OnSessionCreated, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, set_OnSessionCreated, arginfo_TElSessionPool_set_OnSessionCreated, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, get_OnSessionReleased, arginfo_TElSessionPool_get_OnSessionReleased, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, set_OnSessionReleased, arginfo_TElSessionPool_set_OnSessionReleased, ZEND_ACC_PUBLIC)
	PHP_ME(TElSessionPool, __construct, arginfo_TElSessionPool___construct, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
	PHP_FE_END
};

void Register_TElSessionPool(TSRMLS_D)
{
	zend_class_entry ce;
	if (TElSessionPool_ce_ptr != NULL)
		return;

	INIT_CLASS_ENTRY(ce, "TElSessionPool", TElSessionPool_methods);
	if (NULL == TComponent_ce_ptr)
		Register_TComponent(TSRMLS_C);
	TElSessionPool_ce_ptr = zend_register_internal_class_ex(&ce, TComponent_ce_ptr, NULL TSRMLS_CC);
}

SB_PHP_FUNCTION(SBSessionPool, FreeSessionContext)
{
	zval *oCtx;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &oCtx, TSBSessionContext_ce_ptr) == SUCCESS)
	{
		SBCheckError(SBSessionPool_FreeSessionContext((TSBSessionContext *)SBGetStructPointer(oCtx TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(TSBSessionContext)" TSRMLS_CC);
	}
}

void Register_SBSessionPool_Aliases(TSRMLS_D)
{
	if (NULL == TElSessionPool_ce_ptr)
		Register_TElSessionPool(TSRMLS_C);
	zend_register_class_alias("ElSessionPool", TElSessionPool_ce_ptr);
}

