#include "sbzlib.h"

SB_PHP_METHOD(TZlibContext, __construct)
{
	if (ZEND_NUM_ARGS() == 0)
	{
		php_sbb_struct * intern = (php_sbb_struct *)zend_object_store_get_object(getThis() TSRMLS_CC);
		intern->data = emalloc(sizeof(TZlibContext));
		intern->len = sizeof(TZlibContext);
		intern->ownData = 1;
	}
	else
		ZEND_WRONG_PARAM_COUNT();
}

SB_PHP_METHOD(TZlibContext, getSizeOf)
{
	if (ZEND_NUM_ARGS() > 0)
		ZEND_WRONG_PARAM_COUNT();

	RETURN_LONG(sizeof(TZlibContext));
}

zend_class_entry *TZlibContext_ce_ptr = NULL;

static zend_function_entry TZlibContext_methods[] = {
	PHP_ME(TZlibContext, __construct, NULL, ZEND_ACC_PUBLIC)
	PHP_ME(TZlibContext, getSizeOf, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
	PHP_FE_END
};

void Register_TZlibContext(TSRMLS_D)
{
	zend_class_entry ce;
	if (TZlibContext_ce_ptr != NULL)
		return;
	INIT_CLASS_ENTRY(ce, "TZlibContext", TZlibContext_methods);
	TZlibContext_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseStruct_ce_ptr, NULL TSRMLS_CC);
}

void SB_CALLBACK TSBZLibOutputFuncRaw(void * _ObjectData, void * Buffer, int32_t Size, void * Param, int8_t * OutResult)
{
	zval **params[3];
	zval * zBuffer;
	zval * zSize;
	zval * zParam;
	zval * pzOutResult = NULL;
	TSRMLS_FETCH();
	MAKE_STD_ZVAL(zBuffer);
	SBInitPointerObject(zBuffer, Buffer TSRMLS_CC);
	MAKE_STD_ZVAL(zSize);
	ZVAL_LONG(zSize, (long)Size);
	MAKE_STD_ZVAL(zParam);
	SBInitPointerObject(zParam, Param TSRMLS_CC);

	params[0] = &zBuffer;
	params[1] = &zSize;
	params[2] = &zParam;
	SBCallEvent((zval *)_ObjectData, &pzOutResult, 3, params TSRMLS_CC);

	zval_ptr_dtor(&zBuffer);
	zval_ptr_dtor(&zSize);
	zval_ptr_dtor(&zParam);
	if (pzOutResult)
	{
		*OutResult = (int8_t)Z_BVAL_P(pzOutResult);
		zval_ptr_dtor(&pzOutResult);
	}
}

SB_PHP_FUNCTION(SBZlib, InitializeCompression)
{
	long l4CompressionLevel;
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ol", &oContext, TZlibContext_ce_ptr, &l4CompressionLevel) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeCompression((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), (int32_t)l4CompressionLevel) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, InitializeDecompression)
{
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O", &oContext, TZlibContext_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeDecompression((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, InitializeDecompression64)
{
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O", &oContext, TZlibContext_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeDecompression64((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, InitializeCompressionEx)
{
	long l4Level;
	long l4WindowBits;
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ol", &oContext, TZlibContext_ce_ptr, &l4Level) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeCompressionEx((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), (int32_t)l4Level) TSRMLS_CC);
	}
	else if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Oll", &oContext, TZlibContext_ce_ptr, &l4Level, &l4WindowBits) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeCompressionEx_1((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), (int32_t)l4Level, (int32_t)l4WindowBits) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, integer) or (&TZlibContext, integer, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, InitializeDecompressionEx)
{
	zend_bool bUseZLib;
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ob", &oContext, TZlibContext_ce_ptr, &bUseZLib) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeDecompressionEx((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), (int8_t)bUseZLib) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, bool)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, InitializeDecompressionEx64)
{
	zend_bool bUseZLib;
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ob", &oContext, TZlibContext_ce_ptr, &bUseZLib) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_InitializeDecompressionEx64((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), (int8_t)bUseZLib) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, bool)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, FinalizeCompressionEx)
{
	SBArrayZValInfo piOutBuffer;
	uint32_t u4OutSizeRaw;
	zval *oContext;
	zval *zpOutBuffer;
	zval *zu4OutSize;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozz", &oContext, TZlibContext_ce_ptr, &zpOutBuffer, &zu4OutSize) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpOutBuffer) == IS_STRING) || (Z_TYPE_P(zpOutBuffer) == IS_ARRAY) || (Z_TYPE_P(zpOutBuffer) == IS_NULL) || ((Z_TYPE_P(zpOutBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpOutBuffer) == TSBPointer_ce_ptr))) && PZVAL_IS_REF(zu4OutSize) && (IS_LONG == Z_TYPE_P(zu4OutSize)))
	{
		if (!SBGetPointerFromZVal(zpOutBuffer, &piOutBuffer TSRMLS_CC)) RETURN_FALSE;
		u4OutSizeRaw = (uint32_t)Z_LVAL_P(zu4OutSize);
		SBCheckError(SBZlib_FinalizeCompressionEx((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), piOutBuffer.data, &u4OutSizeRaw) TSRMLS_CC);
		SBFreePointerZValInfo(&piOutBuffer);
		ZVAL_LONG(zu4OutSize, (long)u4OutSizeRaw);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, TSBPointer|array of byte|string|NULL, &integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, FinalizeDecompressionEx)
{
	zval *oContext;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O", &oContext, TZlibContext_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oContext))
	{
		SBCheckError(SBZlib_FinalizeDecompressionEx((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, Compress)
{
	long u4InSize;
	SBArrayZValInfo piInBuffer;
	SBArrayZValInfo piOutBuffer;
	uint32_t u4OutSizeRaw;
	zval *oContext;
	zval *zpInBuffer;
	zval *zpOutBuffer;
	zval *zu4OutSize;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozlzz", &oContext, TZlibContext_ce_ptr, &zpInBuffer, &u4InSize, &zpOutBuffer, &zu4OutSize) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpInBuffer) == IS_STRING) || (Z_TYPE_P(zpInBuffer) == IS_ARRAY) || (Z_TYPE_P(zpInBuffer) == IS_NULL) || ((Z_TYPE_P(zpInBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpInBuffer) == TSBPointer_ce_ptr))) && ((Z_TYPE_P(zpOutBuffer) == IS_STRING) || (Z_TYPE_P(zpOutBuffer) == IS_ARRAY) || (Z_TYPE_P(zpOutBuffer) == IS_NULL) || ((Z_TYPE_P(zpOutBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpOutBuffer) == TSBPointer_ce_ptr))) && PZVAL_IS_REF(zu4OutSize) && (IS_LONG == Z_TYPE_P(zu4OutSize)))
	{
		if (!SBGetPointerFromZVal(zpInBuffer, &piInBuffer TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetPointerFromZVal(zpOutBuffer, &piOutBuffer TSRMLS_CC)) RETURN_FALSE;
		u4OutSizeRaw = (uint32_t)Z_LVAL_P(zu4OutSize);
		SBCheckError(SBZlib_Compress((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), piInBuffer.data, (uint32_t)u4InSize, piOutBuffer.data, &u4OutSizeRaw) TSRMLS_CC);
		SBFreePointerZValInfo(&piInBuffer);
		SBFreePointerZValInfo(&piOutBuffer);
		ZVAL_LONG(zu4OutSize, (long)u4OutSizeRaw);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, TSBPointer|array of byte|string|NULL, integer, TSBPointer|array of byte|string|NULL, &integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, Decompress)
{
	long u4InSize;
	SBArrayZValInfo piInBuffer;
	SBArrayZValInfo piOutBuffer;
	uint32_t u4OutSizeRaw;
	zval *oContext;
	zval *zpInBuffer;
	zval *zpOutBuffer;
	zval *zu4OutSize;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozlzz", &oContext, TZlibContext_ce_ptr, &zpInBuffer, &u4InSize, &zpOutBuffer, &zu4OutSize) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpInBuffer) == IS_STRING) || (Z_TYPE_P(zpInBuffer) == IS_ARRAY) || (Z_TYPE_P(zpInBuffer) == IS_NULL) || ((Z_TYPE_P(zpInBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpInBuffer) == TSBPointer_ce_ptr))) && ((Z_TYPE_P(zpOutBuffer) == IS_STRING) || (Z_TYPE_P(zpOutBuffer) == IS_ARRAY) || (Z_TYPE_P(zpOutBuffer) == IS_NULL) || ((Z_TYPE_P(zpOutBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpOutBuffer) == TSBPointer_ce_ptr))) && PZVAL_IS_REF(zu4OutSize) && (IS_LONG == Z_TYPE_P(zu4OutSize)))
	{
		if (!SBGetPointerFromZVal(zpInBuffer, &piInBuffer TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetPointerFromZVal(zpOutBuffer, &piOutBuffer TSRMLS_CC)) RETURN_FALSE;
		u4OutSizeRaw = (uint32_t)Z_LVAL_P(zu4OutSize);
		SBCheckError(SBZlib_Decompress((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), piInBuffer.data, (uint32_t)u4InSize, piOutBuffer.data, &u4OutSizeRaw) TSRMLS_CC);
		SBFreePointerZValInfo(&piInBuffer);
		SBFreePointerZValInfo(&piOutBuffer);
		ZVAL_LONG(zu4OutSize, (long)u4OutSizeRaw);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, TSBPointer|array of byte|string|NULL, integer, TSBPointer|array of byte|string|NULL, &integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, CompressEx)
{
	long u4InSize;
	SBArrayZValInfo piInBuffer;
	SBArrayZValInfo piOutBuffer;
	uint32_t u4OutSizeRaw;
	zval *oContext;
	zval *zpInBuffer;
	zval *zpOutBuffer;
	zval *zu4OutSize;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozlzz", &oContext, TZlibContext_ce_ptr, &zpInBuffer, &u4InSize, &zpOutBuffer, &zu4OutSize) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpInBuffer) == IS_STRING) || (Z_TYPE_P(zpInBuffer) == IS_ARRAY) || (Z_TYPE_P(zpInBuffer) == IS_NULL) || ((Z_TYPE_P(zpInBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpInBuffer) == TSBPointer_ce_ptr))) && ((Z_TYPE_P(zpOutBuffer) == IS_STRING) || (Z_TYPE_P(zpOutBuffer) == IS_ARRAY) || (Z_TYPE_P(zpOutBuffer) == IS_NULL) || ((Z_TYPE_P(zpOutBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpOutBuffer) == TSBPointer_ce_ptr))) && PZVAL_IS_REF(zu4OutSize) && (IS_LONG == Z_TYPE_P(zu4OutSize)))
	{
		if (!SBGetPointerFromZVal(zpInBuffer, &piInBuffer TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetPointerFromZVal(zpOutBuffer, &piOutBuffer TSRMLS_CC)) RETURN_FALSE;
		u4OutSizeRaw = (uint32_t)Z_LVAL_P(zu4OutSize);
		SBCheckError(SBZlib_CompressEx((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), piInBuffer.data, (uint32_t)u4InSize, piOutBuffer.data, &u4OutSizeRaw) TSRMLS_CC);
		SBFreePointerZValInfo(&piInBuffer);
		SBFreePointerZValInfo(&piOutBuffer);
		ZVAL_LONG(zu4OutSize, (long)u4OutSizeRaw);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, TSBPointer|array of byte|string|NULL, integer, TSBPointer|array of byte|string|NULL, &integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBZlib, DecompressEx)
{
	long u4InSize;
	SBArrayZValInfo piInBuffer;
	SBArrayZValInfo piParam;
	void *pzOutputFunc;
	zval *oContext;
	zval *zOutputFunc;
	zval *zpInBuffer;
	zval *zpParam;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "Ozlzz", &oContext, TZlibContext_ce_ptr, &zpInBuffer, &u4InSize, &zOutputFunc, &zpParam) == SUCCESS) && PZVAL_IS_REF(oContext) && ((Z_TYPE_P(zpInBuffer) == IS_STRING) || (Z_TYPE_P(zpInBuffer) == IS_ARRAY) || (Z_TYPE_P(zpInBuffer) == IS_NULL) || ((Z_TYPE_P(zpInBuffer) == IS_OBJECT) && (Z_OBJCE_P(zpInBuffer) == TSBPointer_ce_ptr))) && ((IS_STRING == Z_TYPE_P(zOutputFunc)) || (IS_ARRAY == Z_TYPE_P(zOutputFunc)) || (IS_CALLABLE == Z_TYPE_P(zOutputFunc)) || (IS_NULL == Z_TYPE_P(zOutputFunc))) && ((Z_TYPE_P(zpParam) == IS_STRING) || (Z_TYPE_P(zpParam) == IS_ARRAY) || (Z_TYPE_P(zpParam) == IS_NULL) || ((Z_TYPE_P(zpParam) == IS_OBJECT) && (Z_OBJCE_P(zpParam) == TSBPointer_ce_ptr))))
	{
		if (!SBGetPointerFromZVal(zpInBuffer, &piInBuffer TSRMLS_CC)) RETURN_FALSE;
		pzOutputFunc = SBSetEventData(zOutputFunc TSRMLS_CC);
		if (!SBGetPointerFromZVal(zpParam, &piParam TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBZlib_DecompressEx((TZlibContext *)SBGetStructPointer(oContext TSRMLS_CC), piInBuffer.data, (uint32_t)u4InSize, pzOutputFunc ? &TSBZLibOutputFuncRaw : NULL, pzOutputFunc, piParam.data) TSRMLS_CC);
		SBFreePointerZValInfo(&piInBuffer);
		SBFreePointerZValInfo(&piParam);
	}
	else
	{
		SBErrorExpectsArguments("(&TZlibContext, TSBPointer|array of byte|string|NULL, integer, TSBZLibOutputFunc|callable|NULL, TSBPointer|array of byte|string|NULL)" TSRMLS_CC);
	}
}

