#ifndef __INC_SBCERTVALIDATOR
#define __INC_SBCERTVALIDATOR

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbstrutils.h"
#include "sbrdn.h"
#include "sbconstants.h"
#include "sbx509.h"
#include "sbx509ext.h"
#include "sbocspcommon.h"
#include "sbocspclient.h"
#include "sbrandom.h"
#include "sbpkicommon.h"
#include "sbcrl.h"
#include "sbcrlstorage.h"
#include "sbcertretriever.h"
#include "sbstringlist.h"
#include "sbpunycode.h"
#ifdef SB_WINDOWS
#include "sbwincertstorage.h"
#endif
#ifdef MACOS
#include "sbapplecommon.h"
#include "sbapplecertstorage.h"
#endif
#include "sbcustomcertstorage.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
#define SB_VALIDATOR_CRL_ERROR_BASE 	1000
#define SB_VALIDATOR_OCSP_ERROR_BASE 	2000
#define SB_VALIDATOR_CRL_ERROR_VALIDATION_FAILED 	1001
#define SB_VALIDATOR_CRL_ERROR_NO_RETRIEVER 	1002
#define SB_VALIDATOR_CRL_ERROR_RETRIEVER_FAILED 	1003
#define SB_VALIDATOR_CRL_ERROR_NO_CRLS_RETRIEVED 	1004
#define SB_VALIDATOR_CRL_ERROR_CERT_REVOKED 	1005
#define SB_VALIDATOR_OCSP_ERROR_VALIDATION_FAILED 	2001
#define SB_VALIDATOR_OCSP_ERROR_NO_CLIENT 	2002
#define SB_VALIDATOR_OCSP_ERROR_CLIENT_FAILED 	2003
#define SB_VALIDATOR_OCSP_ERROR_INVALID_RESPONSE 	2004
#define SB_VALIDATOR_OCSP_ERROR_CERT_REVOKED 	2005

typedef TElClassHandle TElX509CertificateValidatorHandle;

typedef TElClassHandle TElX509CertificateValidatorLoggerHandle;

typedef TElClassHandle TElX509CertificateValidationResultHandle;

typedef TElClassHandle TElX509CachedCertificateHandle;

typedef TElClassHandle TElCacheCertStorageHandle;

typedef void (SB_CALLBACK *TSBCRLNeededEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElCustomCRLStorageHandle * CRLs);

typedef void (SB_CALLBACK *TSBCACertificateRetrievedEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElX509CertificateHandle CACertificate);

typedef void (SB_CALLBACK *TSBCRLRetrievedEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCertificateRevocationListHandle CRL);

typedef void (SB_CALLBACK *TSBAfterCRLUseEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElCertificateRevocationListHandle CRL);

typedef void (SB_CALLBACK *TSBAfterOCSPResponseUseEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElOCSPResponseHandle Response);

typedef void (SB_CALLBACK *TSBOCSPResponseSignerValidEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElOCSPResponseHandle Response, TElX509CertificateHandle SignerCertificate, int8_t * SignerValid);

typedef void (SB_CALLBACK *TSBBeforeCertificateRetrieverUseEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCustomCertificateRetrieverHandle * Retriever);

typedef void (SB_CALLBACK *TSBBeforeCRLRetrieverUseEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCustomCRLRetrieverHandle * Retriever);

typedef void (SB_CALLBACK *TSBBeforeOCSPClientUseEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, const char * pcOCSPLocation, int32_t szOCSPLocation, TElOCSPClientHandle * OCSPClient);

typedef void (SB_CALLBACK *TSBCertificateValidatorCRLErrorEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, const char * pcLocation, int32_t szLocation, TElCustomCRLRetrieverHandle Retriever, int32_t ErrorCode);

typedef void (SB_CALLBACK *TSBCertificateValidatorOCSPErrorEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, const char * pcLocation, int32_t szLocation, TElOCSPClientHandle Client, int32_t ErrorCode);

typedef void (SB_CALLBACK *TSBCACertificateNeededEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle * CACertificate);

typedef void (SB_CALLBACK *TSBBeforeCertificateValidationEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate);

typedef void (SB_CALLBACK *TSBAfterCertificateValidationEvent)(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason, int8_t * DoContinue);

typedef uint8_t TSBX509RevocationCheckPreferenceRaw;

typedef enum
{
	rcpPreferCRL = 0,
	rcpPreferOCSP = 1,
	rcpCheckBoth = 2
} TSBX509RevocationCheckPreference;

#ifdef SB_USE_CLASS_TELX509CERTIFICATEVALIDATOR
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_InitializeWinStorages(TElX509CertificateValidatorHandle _Handle);
#endif
#ifdef MACOS
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_InitializeAppleStorages(TElX509CertificateValidatorHandle _Handle);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_Validate(TElX509CertificateValidatorHandle _Handle, TElX509CertificateHandle Certificate, TElCustomCertStorageHandle AdditionalCertificates, int8_t CompleteChainValidation, int64_t ValidityMoment, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_Validate_1(TElX509CertificateValidatorHandle _Handle, TElX509CertificateHandle Certificate, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ValidateForSMIME(TElX509CertificateValidatorHandle _Handle, TElX509CertificateHandle Certificate, const char * pcEMailAddress, int32_t szEMailAddress, TElCustomCertStorageHandle AdditionalCertificates, int8_t CompleteChainValidation, int64_t ValidityMoment, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ValidateForSSL(TElX509CertificateValidatorHandle _Handle, TElX509CertificateHandle Certificate, const char * pcDomainName, int32_t szDomainName, const char * pcIPAddress, int32_t szIPAddress, TSBHostRoleRaw HostRole, TElCustomCertStorageHandle AdditionalCertificates, int8_t CompleteChainValidation, int64_t ValidityMoment, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ValidateForSSL_1(TElX509CertificateValidatorHandle _Handle, TElX509CertificateHandle Certificate, const char * pcDomainName, int32_t szDomainName, const char * pcIPAddress, int32_t szIPAddress, TSBHostRoleRaw HostRole, TElCustomCertStorageHandle AdditionalCertificates, int8_t CompleteChainValidation, int64_t ValidityMoment, int8_t InternalValidation, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ValidateForTimestamping(TElX509CertificateValidatorHandle _Handle, TElX509CertificateHandle Certificate, TElCustomCertStorageHandle AdditionalCertificates, int8_t CompleteChainValidation, int64_t ValidityMoment, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_AddTrustedCertificates(TElX509CertificateValidatorHandle _Handle, TElCustomCertStorageHandle Storage);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearTrustedCertificates(TElX509CertificateValidatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_AddBlockedCertificates(TElX509CertificateValidatorHandle _Handle, TElCustomCertStorageHandle Storage);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearBlockedCertificates(TElX509CertificateValidatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_AddKnownCertificates(TElX509CertificateValidatorHandle _Handle, TElCustomCertStorageHandle Storage);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearKnownCertificates(TElX509CertificateValidatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_AddKnownCRLs(TElX509CertificateValidatorHandle _Handle, TElCustomCRLStorageHandle Storage);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearKnownCRLs(TElX509CertificateValidatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_AddKnownOCSPResponses(TElX509CertificateValidatorHandle _Handle, TElOCSPResponseHandle Response);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearKnownOCSPResponses(TElX509CertificateValidatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ResetCertificateCache();
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ResetCertificateCache_1(TElX509CertificateValidatorHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearOutdatedCacheRecords(int64_t ClearMoment, int32_t CacheValidityTime);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_ClearOutdatedCacheRecords_1(TElX509CertificateValidatorHandle _Handle, int64_t ClearMoment, int32_t CacheValidityTime);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_UsedCertificates(TElX509CertificateValidatorHandle _Handle, TElMemoryCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_UsedCRLs(TElX509CertificateValidatorHandle _Handle, TElMemoryCRLStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_UsedOCSPResponses(TElX509CertificateValidatorHandle _Handle, TListHandle * OutResult);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_WinStorageTrust(TElX509CertificateValidatorHandle _Handle, TElWinCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_WinStorageCA(TElX509CertificateValidatorHandle _Handle, TElWinCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_WinStorageBlocked(TElX509CertificateValidatorHandle _Handle, TElWinCertStorageHandle * OutResult);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_Logger(TElX509CertificateValidatorHandle _Handle, TElX509CertificateValidatorLoggerHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_Logger(TElX509CertificateValidatorHandle _Handle, TElX509CertificateValidatorLoggerHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_InternalLogger(TElX509CertificateValidatorHandle _Handle, TElX509CertificateValidatorLoggerHandle * OutResult);
#ifdef MACOS
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_AppleStorageCA(TElX509CertificateValidatorHandle _Handle, TElAppleCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_AppleStorageTrust(TElX509CertificateValidatorHandle _Handle, TElAppleCertStorageHandle * OutResult);
#endif
#ifndef LINUX
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreSystemTrust(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreSystemTrust(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_UseSystemStorages(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_UseSystemStorages(TElX509CertificateValidatorHandle _Handle, int8_t Value);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_CheckCRL(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_CheckCRL(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_CheckOCSP(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_CheckOCSP(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_CheckValidityPeriodForTrusted(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_CheckValidityPeriodForTrusted(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreCAKeyUsage(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreCAKeyUsage(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreRevocationKeyUsage(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreRevocationKeyUsage(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreSSLKeyUsage(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreSSLKeyUsage(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreBadOCSPChains(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreBadOCSPChains(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreCABasicConstraints(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreCABasicConstraints(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_IgnoreCANameConstraints(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_IgnoreCANameConstraints(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_MandatoryCRLCheck(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_MandatoryCRLCheck(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_MandatoryOCSPCheck(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_MandatoryOCSPCheck(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_MandatoryRevocationCheck(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_MandatoryRevocationCheck(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_ValidateInvalidCertificates(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_ValidateInvalidCertificates(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_ForceCompleteChainValidationForTrusted(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_ForceCompleteChainValidationForTrusted(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_ForceRevocationCheckForRoot(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_ForceRevocationCheckForRoot(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OfflineMode(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OfflineMode(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_RevocationMomentGracePeriod(TElX509CertificateValidatorHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_RevocationMomentGracePeriod(TElX509CertificateValidatorHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_ImplicitlyTrustSelfSignedCertificates(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_ImplicitlyTrustSelfSignedCertificates(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_PromoteLongOCSPResponses(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_PromoteLongOCSPResponses(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_RevocationCheckPreference(TElX509CertificateValidatorHandle _Handle, TSBX509RevocationCheckPreferenceRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_RevocationCheckPreference(TElX509CertificateValidatorHandle _Handle, TSBX509RevocationCheckPreferenceRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_LookupCRLByNameIfDPNotPresent(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_LookupCRLByNameIfDPNotPresent(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_SkipSubjectNameIfAltNameExists(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_SkipSubjectNameIfAltNameExists(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_CacheValidityTime(TElX509CertificateValidatorHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_CacheValidityTime(TElX509CertificateValidatorHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_CacheValidationResults(TElX509CertificateValidatorHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_CacheValidationResults(TElX509CertificateValidatorHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnCRLNeeded(TElX509CertificateValidatorHandle _Handle, TSBCRLNeededEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnCRLNeeded(TElX509CertificateValidatorHandle _Handle, TSBCRLNeededEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnCRLRetrieved(TElX509CertificateValidatorHandle _Handle, TSBCRLRetrievedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnCRLRetrieved(TElX509CertificateValidatorHandle _Handle, TSBCRLRetrievedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnBeforeCRLRetrieverUse(TElX509CertificateValidatorHandle _Handle, TSBBeforeCRLRetrieverUseEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnBeforeCRLRetrieverUse(TElX509CertificateValidatorHandle _Handle, TSBBeforeCRLRetrieverUseEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnBeforeCertificateRetrieverUse(TElX509CertificateValidatorHandle _Handle, TSBBeforeCertificateRetrieverUseEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnBeforeCertificateRetrieverUse(TElX509CertificateValidatorHandle _Handle, TSBBeforeCertificateRetrieverUseEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnCACertificateRetrieved(TElX509CertificateValidatorHandle _Handle, TSBCACertificateRetrievedEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnCACertificateRetrieved(TElX509CertificateValidatorHandle _Handle, TSBCACertificateRetrievedEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnBeforeOCSPClientUse(TElX509CertificateValidatorHandle _Handle, TSBBeforeOCSPClientUseEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnBeforeOCSPClientUse(TElX509CertificateValidatorHandle _Handle, TSBBeforeOCSPClientUseEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnBeforeCertificateValidation(TElX509CertificateValidatorHandle _Handle, TSBBeforeCertificateValidationEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnBeforeCertificateValidation(TElX509CertificateValidatorHandle _Handle, TSBBeforeCertificateValidationEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnAfterCertificateValidation(TElX509CertificateValidatorHandle _Handle, TSBAfterCertificateValidationEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnAfterCertificateValidation(TElX509CertificateValidatorHandle _Handle, TSBAfterCertificateValidationEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnCACertificateNeeded(TElX509CertificateValidatorHandle _Handle, TSBCACertificateNeededEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnCACertificateNeeded(TElX509CertificateValidatorHandle _Handle, TSBCACertificateNeededEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnAfterCRLUse(TElX509CertificateValidatorHandle _Handle, TSBAfterCRLUseEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnAfterCRLUse(TElX509CertificateValidatorHandle _Handle, TSBAfterCRLUseEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnAfterOCSPResponseUse(TElX509CertificateValidatorHandle _Handle, TSBAfterOCSPResponseUseEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnAfterOCSPResponseUse(TElX509CertificateValidatorHandle _Handle, TSBAfterOCSPResponseUseEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnOCSPResponseSignerValid(TElX509CertificateValidatorHandle _Handle, TSBOCSPResponseSignerValidEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnOCSPResponseSignerValid(TElX509CertificateValidatorHandle _Handle, TSBOCSPResponseSignerValidEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnCRLError(TElX509CertificateValidatorHandle _Handle, TSBCertificateValidatorCRLErrorEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnCRLError(TElX509CertificateValidatorHandle _Handle, TSBCertificateValidatorCRLErrorEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_get_OnOCSPError(TElX509CertificateValidatorHandle _Handle, TSBCertificateValidatorOCSPErrorEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_set_OnOCSPError(TElX509CertificateValidatorHandle _Handle, TSBCertificateValidatorOCSPErrorEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidator_Create(TComponentHandle AOwner, TElX509CertificateValidatorHandle * OutResult);
#endif /* SB_USE_CLASS_TELX509CERTIFICATEVALIDATOR */

#ifdef SB_USE_CLASS_TELX509CERTIFICATEVALIDATORLOGGER
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidatorLogger_Reset(TElX509CertificateValidatorLoggerHandle _Handle);
#ifdef SB_WINDOWS
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidatorLogger_get_Log(TElX509CertificateValidatorLoggerHandle _Handle, TStringListHandle * OutResult);
#else
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidatorLogger_get_Log(TElX509CertificateValidatorLoggerHandle _Handle, TElStringListHandle * OutResult);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidatorLogger_Create(TElX509CertificateValidatorLoggerHandle * OutResult);
#endif /* SB_USE_CLASS_TELX509CERTIFICATEVALIDATORLOGGER */

#ifdef SB_USE_CLASS_TELX509CERTIFICATEVALIDATIONRESULT
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_EqualParams(TElX509CertificateValidationResultHandle _Handle, TElX509CertificateValidationResultHandle Value, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_LastValidatedTime(TElX509CertificateValidationResultHandle _Handle, int64_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_LastValidatedTime(TElX509CertificateValidationResultHandle _Handle, int64_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_Validity(TElX509CertificateValidationResultHandle _Handle, TSBCertificateValidityRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_Validity(TElX509CertificateValidationResultHandle _Handle, TSBCertificateValidityRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_Reason(TElX509CertificateValidationResultHandle _Handle, TSBCertificateValidityReasonRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_Reason(TElX509CertificateValidationResultHandle _Handle, TSBCertificateValidityReasonRaw Value);
#ifndef LINUX
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreSystemTrust(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreSystemTrust(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_UseSystemStorages(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_UseSystemStorages(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
#endif
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_CheckCRL(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_CheckCRL(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_CheckOCSP(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_CheckOCSP(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_CheckValidityPeriodForTrusted(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_CheckValidityPeriodForTrusted(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreCAKeyUsage(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreCAKeyUsage(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreRevocationKeyUsage(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreRevocationKeyUsage(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreSSLKeyUsage(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreSSLKeyUsage(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreBadOCSPChains(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreBadOCSPChains(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreCABasicConstraints(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreCABasicConstraints(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_IgnoreCANameConstraints(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_IgnoreCANameConstraints(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_MandatoryCRLCheck(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_MandatoryCRLCheck(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_MandatoryOCSPCheck(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_MandatoryOCSPCheck(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_MandatoryRevocationCheck(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_MandatoryRevocationCheck(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_ValidateInvalidCertificates(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_ValidateInvalidCertificates(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_ForceCompleteChainValidationForTrusted(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_ForceCompleteChainValidationForTrusted(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_ForceRevocationCheckForRoot(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_ForceRevocationCheckForRoot(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_OfflineMode(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_OfflineMode(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_RevocationMomentGracePeriod(TElX509CertificateValidationResultHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_RevocationMomentGracePeriod(TElX509CertificateValidationResultHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_ImplicitlyTrustSelfSignedCertificates(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_ImplicitlyTrustSelfSignedCertificates(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_PromoteLongOCSPResponses(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_PromoteLongOCSPResponses(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_RevocationCheckPreference(TElX509CertificateValidationResultHandle _Handle, TSBX509RevocationCheckPreferenceRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_RevocationCheckPreference(TElX509CertificateValidationResultHandle _Handle, TSBX509RevocationCheckPreferenceRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_LookupCRLByNameIfDPNotPresent(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_LookupCRLByNameIfDPNotPresent(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_get_SkipSubjectNameIfAltNameExists(TElX509CertificateValidationResultHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_set_SkipSubjectNameIfAltNameExists(TElX509CertificateValidationResultHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElX509CertificateValidationResult_Create(TElX509CertificateValidatorHandle Validator, TElX509CertificateValidationResultHandle * OutResult);
#endif /* SB_USE_CLASS_TELX509CERTIFICATEVALIDATIONRESULT */

#ifdef SB_USE_CLASS_TELX509CACHEDCERTIFICATE
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_AddValidationResult(TElX509CachedCertificateHandle _Handle, TElX509CertificateValidationResultHandle Res, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_RemoveValidationResult(TElX509CachedCertificateHandle _Handle, int32_t Index);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_FindResultByValidityMoment(TElX509CachedCertificateHandle _Handle, int64_t ValidityMoment, int32_t CacheValidityTime, TElX509CertificateValidationResultHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_IsRevoked(TElX509CachedCertificateHandle _Handle, int64_t ValidityMoment, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_IsPermanentlyInvalid(TElX509CachedCertificateHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_ClassType(TClassHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_get_ValidationResults(TElX509CachedCertificateHandle _Handle, int32_t Index, TElX509CertificateValidationResultHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_get_ValidationResultCount(TElX509CachedCertificateHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElX509CachedCertificate_Create(TComponentHandle AOwner, TElX509CachedCertificateHandle * OutResult);
#endif /* SB_USE_CLASS_TELX509CACHEDCERTIFICATE */

#ifdef SB_USE_CLASS_TELCACHECERTSTORAGE
SB_IMPORT uint32_t SB_APIENTRY TElCacheCertStorage_BeginWrite(TElCacheCertStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCacheCertStorage_EndWrite(TElCacheCertStorageHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElCacheCertStorage_Add(TElCacheCertStorageHandle _Handle, TElX509CertificateHandle X509Certificate, int64_t ValidityMoment, TSBCertificateValidityRaw Validity, TSBCertificateValidityReasonRaw Reason, TElX509CertificateValidatorHandle Validator);
SB_IMPORT uint32_t SB_APIENTRY TElCacheCertStorage_Add_1(TElMemoryCertStorageHandle _Handle, TElX509CertificateHandle X509Certificate, int8_t CopyPrivateKey);
SB_IMPORT uint32_t SB_APIENTRY TElCacheCertStorage_Create(TComponentHandle Owner, TElMemoryCertStorageHandle * OutResult);
#endif /* SB_USE_CLASS_TELCACHECERTSTORAGE */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TElX509CertificateValidator_ce_ptr;
extern zend_class_entry *TElX509CertificateValidatorLogger_ce_ptr;
extern zend_class_entry *TElX509CertificateValidationResult_ce_ptr;
extern zend_class_entry *TElX509CachedCertificate_ce_ptr;
extern zend_class_entry *TElCacheCertStorage_ce_ptr;

void SB_CALLBACK TSBCRLNeededEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElCustomCRLStorageHandle * CRLs);
void SB_CALLBACK TSBCACertificateRetrievedEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElX509CertificateHandle CACertificate);
void SB_CALLBACK TSBCRLRetrievedEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCertificateRevocationListHandle CRL);
void SB_CALLBACK TSBAfterCRLUseEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElCertificateRevocationListHandle CRL);
void SB_CALLBACK TSBAfterOCSPResponseUseEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElOCSPResponseHandle Response);
void SB_CALLBACK TSBOCSPResponseSignerValidEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TElOCSPResponseHandle Response, TElX509CertificateHandle SignerCertificate, int8_t * SignerValid);
void SB_CALLBACK TSBBeforeCertificateRetrieverUseEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCustomCertificateRetrieverHandle * Retriever);
void SB_CALLBACK TSBBeforeCRLRetrieverUseEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TSBGeneralNameRaw NameType, const char * pcLocation, int32_t szLocation, TElCustomCRLRetrieverHandle * Retriever);
void SB_CALLBACK TSBBeforeOCSPClientUseEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, const char * pcOCSPLocation, int32_t szOCSPLocation, TElOCSPClientHandle * OCSPClient);
void SB_CALLBACK TSBCertificateValidatorCRLErrorEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, const char * pcLocation, int32_t szLocation, TElCustomCRLRetrieverHandle Retriever, int32_t ErrorCode);
void SB_CALLBACK TSBCertificateValidatorOCSPErrorEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, const char * pcLocation, int32_t szLocation, TElOCSPClientHandle Client, int32_t ErrorCode);
void SB_CALLBACK TSBCACertificateNeededEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle * CACertificate);
void SB_CALLBACK TSBBeforeCertificateValidationEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate);
void SB_CALLBACK TSBAfterCertificateValidationEventRaw(void * _ObjectData, TObjectHandle Sender, TElX509CertificateHandle Certificate, TElX509CertificateHandle CACertificate, TSBCertificateValidityRaw * Validity, TSBCertificateValidityReasonRaw * Reason, int8_t * DoContinue);
void Register_TElX509CertificateValidator(TSRMLS_D);
void Register_TElX509CertificateValidatorLogger(TSRMLS_D);
void Register_TElX509CertificateValidationResult(TSRMLS_D);
void Register_TElX509CachedCertificate(TSRMLS_D);
void Register_TElCacheCertStorage(TSRMLS_D);
SB_PHP_FUNCTION(SBCertValidator, GetCertificateCache);
void Register_SBCertValidator_Constants(int module_number TSRMLS_DC);
void Register_SBCertValidator_Enum_Flags(TSRMLS_D);

#ifdef __cplusplus
extern "C" {
#endif

#ifdef SB_USE_GLOBAL_PROCS_CERTVALIDATOR
SB_IMPORT uint32_t SB_APIENTRY SBCertValidator_GetCertificateCache(TElCacheCertStorageHandle * OutResult);
#endif /* SB_USE_GLOBAL_PROCS_CERTVALIDATOR */

#ifdef __cplusplus
};	/* extern "C" */
#endif

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBCERTVALIDATOR */
