#ifndef __INC_SBTAR
#define __INC_SBTAR

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbconstants.h"
#include "sbstrutils.h"
#include "sbstreams.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
#define SB_SErrorCreateTarFile 	"TAR file can\'t be created"
#define SB_SErrorCreateFile 	"File can\'t be created"
#define SB_SErrorOpenFile 	"TAR file can\'t be open"
#define SB_SErrorIndexFile 	"Out of TAR library index"
#define SB_SErrorRepos 	"Out of TAR"
#define SB_SErrorCorrupted 	"Corrupted data"
#define SB_SErrorRead 	"Error while reading file"
#define SB_SErrorWrite 	"Error while writing file"
#define SB_SErrorAttr 	"Error while setting file attributes"
#ifndef SB_TarMagic
#define SB_TarMagic 	"ustar   "
#endif
#define SB_BaseSize 	257
#ifndef SB_UStarSize
#define SB_UStarSize 	88
#endif

typedef TElClassHandle TElTarReaderLowHandle;

typedef TElClassHandle TElTarWriterLowHandle;

#pragma pack(1)
typedef struct 
{
	void * Name;
	void * Mode;
	void * UID;
	void * GID;
	void * Size;
	void * MTime;
	void * CheckSum;
	void * Link;
	void * LinkName;
} TElBaseTarHeaderLow;

#pragma pack(1)
typedef struct 
{
	void * Name;
	int64_t Size;
	double MTime;
	uint8_t Link;
	void * LinkName;
} TElFileTarHeaderLow;

#pragma pack(1)
typedef struct 
{
	void * Magic;
	void * UName;
	void * GName;
	void * DevMajor;
	void * DevMinor;
} TElUStarTarHeaderLow;

#pragma pack(1)
typedef struct 
{
	TElBaseTarHeaderLow Base;
	int8_t HasUStar;
	TElUStarTarHeaderLow UStar;
	int64_t FilePos;
	int64_t FileSize;
} TElTarEntryLow;

#ifdef SB_USE_CLASS_TELTARREADERLOW
SB_IMPORT uint32_t SB_APIENTRY TElTarReaderLow_ExtractToStream(TElTarReaderLowHandle _Handle, int32_t Index, TStreamHandle Stream, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElTarReaderLow_LoadLibrary(TElTarReaderLowHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElTarReaderLow_get_Files(TElTarReaderLowHandle _Handle, int32_t FileIndex, TElFileTarHeaderLow * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElTarReaderLow_get_FilesCount(TElTarReaderLowHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElTarReaderLow_Create(const TStreamHandle TarStream, TElTarReaderLowHandle * OutResult);
#endif /* SB_USE_CLASS_TELTARREADERLOW */

#ifdef SB_USE_CLASS_TELTARWRITERLOW
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_AddFile(TElTarWriterLowHandle _Handle, TStreamHandle Stream, const char * pcFileName, int32_t szFileName, int64_t Date, int32_t Mode);
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_Flush(TElTarWriterLowHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_get_UID(TElTarWriterLowHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_set_UID(TElTarWriterLowHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_get_GID(TElTarWriterLowHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_set_GID(TElTarWriterLowHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElTarWriterLow_Create(const TStreamHandle TarStream, TElTarWriterLowHandle * OutResult);
#endif /* SB_USE_CLASS_TELTARWRITERLOW */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TElBaseTarHeaderLow_ce_ptr;
extern zend_class_entry *TElFileTarHeaderLow_ce_ptr;
extern zend_class_entry *TElUStarTarHeaderLow_ce_ptr;
extern zend_class_entry *TElTarEntryLow_ce_ptr;
extern zend_class_entry *TElTarReaderLow_ce_ptr;
extern zend_class_entry *TElTarWriterLow_ce_ptr;

void Register_TElBaseTarHeaderLow(TSRMLS_D);
void Register_TElFileTarHeaderLow(TSRMLS_D);
void Register_TElUStarTarHeaderLow(TSRMLS_D);
void Register_TElTarEntryLow(TSRMLS_D);
void Register_TElTarReaderLow(TSRMLS_D);
void Register_TElTarWriterLow(TSRMLS_D);
void Register_SBTar_Constants(int module_number TSRMLS_DC);

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBTAR */

