#ifndef __INC_SBTSPCLIENT
#define __INC_SBTSPCLIENT

#if _MSC_VER > 1000
#  pragma once
#endif // _MSC_VER > 1000

#include "sbdefs.h"
#include "sbphpcore.h"
#include "sbsystem.h"
#include "sbtypes.h"
#include "sbutils.h"
#include "sbencoding.h"
#include "sbconstants.h"
#include "sbpem.h"
#include "sbasn1.h"
#include "sbasn1tree.h"
#include "sbx509.h"
#include "sbx509ext.h"
#include "sbpkcs7.h"
#include "sbpkcs7utils.h"
#include "sbpkicommon.h"
#include "sbtspcommon.h"
#include "sbcustomcertstorage.h"

#pragma pack(push, 1)

#ifdef __cplusplus
namespace SecureBlackbox {
#endif

#ifdef __cplusplus
extern "C" {
#endif
typedef TElClassHandle TElClientTSPInfoHandle;

typedef TElClientTSPInfoHandle ElClientTSPInfoHandle;

typedef TElClassHandle TElCustomTSPClientHandle;

typedef TElCustomTSPClientHandle ElCustomTSPClientHandle;

typedef TElClassHandle TElFileTSPClientHandle;

typedef TElFileTSPClientHandle ElFileTSPClientHandle;

typedef uint8_t TSBTSPOptionRaw;

typedef enum
{
	tsoIncludeReqPolicy = 0,
	tsoIgnoreBadSignature = 1,
	tsoIgnoreBadNonce = 2
} TSBTSPOption;

typedef uint32_t TSBTSPOptionsRaw;

typedef enum 
{
	f_tsoIncludeReqPolicy = 1,
	f_tsoIgnoreBadSignature = 2,
	f_tsoIgnoreBadNonce = 4
} TSBTSPOptions;

typedef uint8_t TSBTSPRequestFormatRaw;

typedef enum
{
	tsfRFC3161 = 0,
	tsfCMS = 1
} TSBTSPRequestFormat;

typedef void (SB_CALLBACK *TSBTSPBeforeSignEvent)(void * _ObjectData, TObjectHandle Sender, TObjectHandle Signer);

typedef void (SB_CALLBACK *TSBTSPErrorEvent)(void * _ObjectData, TObjectHandle Sender, int32_t ResultCode);

typedef void (SB_CALLBACK *TSBTimestampNeededEvent)(void * _ObjectData, TObjectHandle Sender, TStreamHandle RequestStream, TStreamHandle ReplyStream, int8_t * Succeeded);

#ifdef SB_USE_CLASS_TELCLIENTTSPINFO
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_ParseCMS(TElClientTSPInfoHandle _Handle, const uint8_t pCMSData[], int32_t szCMSData, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_ParseCMS_1(TElClientTSPInfoHandle _Handle, const uint8_t pCMSData[], int32_t szCMSData, int8_t NoOuterInfo, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_Reset(TElClientTSPInfoHandle _Handle);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_GetSignerCertificate(TElClientTSPInfoHandle _Handle, TElX509CertificateHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_Nonce(TElClientTSPInfoHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_set_Nonce(TElClientTSPInfoHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_Certificates(TElClientTSPInfoHandle _Handle, TElCustomCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_MessageImprint(TElClientTSPInfoHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_ResponseNonce(TElClientTSPInfoHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_CMS(TElClientTSPInfoHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_IgnoreBadSignature(TElClientTSPInfoHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_set_IgnoreBadSignature(TElClientTSPInfoHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_LastValidationResult(TElClientTSPInfoHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_HashAlgorithm(TElClientTSPInfoHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_get_HashedData(TElClientTSPInfoHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElClientTSPInfo_Create(TElClientTSPInfoHandle * OutResult);
#endif /* SB_USE_CLASS_TELCLIENTTSPINFO */

#ifdef SB_USE_CLASS_TELCUSTOMTSPCLIENT
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_Timestamp(TElCustomTSPClientHandle _Handle, const uint8_t pHashedData[], int32_t szHashedData, TSBPKIStatusRaw * ServerResult, int32_t * FailureInfo, uint8_t pReplyCMS[], int32_t * szReplyCMS, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_TSPInfo(TElCustomTSPClientHandle _Handle, TElClientTSPInfoHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_ReqPolicy(TElCustomTSPClientHandle _Handle, uint8_t pOutResult[], int32_t * szOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_ReqPolicy(TElCustomTSPClientHandle _Handle, const uint8_t pValue[], int32_t szValue);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_HashAlgorithm(TElCustomTSPClientHandle _Handle, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_HashAlgorithm(TElCustomTSPClientHandle _Handle, int32_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_IncludeCertificates(TElCustomTSPClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_IncludeCertificates(TElCustomTSPClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_Options(TElCustomTSPClientHandle _Handle, TSBTSPOptionsRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_Options(TElCustomTSPClientHandle _Handle, TSBTSPOptionsRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_RequestFormat(TElCustomTSPClientHandle _Handle, TSBTSPRequestFormatRaw * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_RequestFormat(TElCustomTSPClientHandle _Handle, TSBTSPRequestFormatRaw Value);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_CertStorage(TElCustomTSPClientHandle _Handle, TElCustomCertStorageHandle * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_CertStorage(TElCustomTSPClientHandle _Handle, TElCustomCertStorageHandle Value);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_OnCertificateValidate(TElCustomTSPClientHandle _Handle, TSBCertificateValidationEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_OnCertificateValidate(TElCustomTSPClientHandle _Handle, TSBCertificateValidationEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_OnBeforeSign(TElCustomTSPClientHandle _Handle, TSBTSPBeforeSignEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_OnBeforeSign(TElCustomTSPClientHandle _Handle, TSBTSPBeforeSignEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_get_OnTSPError(TElCustomTSPClientHandle _Handle, TSBTSPErrorEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_set_OnTSPError(TElCustomTSPClientHandle _Handle, TSBTSPErrorEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElCustomTSPClient_Create(TComponentHandle Owner, TElCustomTSPClientHandle * OutResult);
#endif /* SB_USE_CLASS_TELCUSTOMTSPCLIENT */

#ifdef SB_USE_CLASS_TELFILETSPCLIENT
SB_IMPORT uint32_t SB_APIENTRY TElFileTSPClient_Timestamp(TElFileTSPClientHandle _Handle, const uint8_t pHashedData[], int32_t szHashedData, TSBPKIStatusRaw * ServerResult, int32_t * FailureInfo, uint8_t pReplyCMS[], int32_t * szReplyCMS, int32_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElFileTSPClient_get_HashOnlyNeeded(TElFileTSPClientHandle _Handle, int8_t * OutResult);
SB_IMPORT uint32_t SB_APIENTRY TElFileTSPClient_set_HashOnlyNeeded(TElFileTSPClientHandle _Handle, int8_t Value);
SB_IMPORT uint32_t SB_APIENTRY TElFileTSPClient_get_OnTimestampNeeded(TElFileTSPClientHandle _Handle, TSBTimestampNeededEvent * pMethodOutResult, void * * pDataOutResult);
SB_IMPORT uint32_t SB_APIENTRY TElFileTSPClient_set_OnTimestampNeeded(TElFileTSPClientHandle _Handle, TSBTimestampNeededEvent pMethodValue, void * pDataValue);
SB_IMPORT uint32_t SB_APIENTRY TElFileTSPClient_Create(TComponentHandle Owner, TElCustomTSPClientHandle * OutResult);
#endif /* SB_USE_CLASS_TELFILETSPCLIENT */

#ifdef __cplusplus
};	/* extern "C" */
#endif

extern zend_class_entry *TElClientTSPInfo_ce_ptr;
extern zend_class_entry *TElCustomTSPClient_ce_ptr;
extern zend_class_entry *TElFileTSPClient_ce_ptr;

void SB_CALLBACK TSBTSPBeforeSignEventRaw(void * _ObjectData, TObjectHandle Sender, TObjectHandle Signer);
void SB_CALLBACK TSBTSPErrorEventRaw(void * _ObjectData, TObjectHandle Sender, int32_t ResultCode);
void SB_CALLBACK TSBTimestampNeededEventRaw(void * _ObjectData, TObjectHandle Sender, TStreamHandle RequestStream, TStreamHandle ReplyStream, int8_t * Succeeded);
void Register_TElClientTSPInfo(TSRMLS_D);
void Register_TElCustomTSPClient(TSRMLS_D);
void Register_TElFileTSPClient(TSRMLS_D);
void Register_SBTSPClient_Enum_Flags(TSRMLS_D);
void Register_SBTSPClient_Aliases(TSRMLS_D);

#ifdef __cplusplus
};	/* namespace SecureBlackbox */
#endif

#pragma pack(pop)

#endif  /* __INC_SBTSPCLIENT */

