<?php 

$OK = true;

// Boolean : in, result

function TestBooleanParameters()
{
  if (!(SBStrUtils\StringEndsWith("test", "st") === true))
  {
    echo "Invalid boolean value\n";
    return false;
  }

  if (!(SBStrUtils\StringIsEmpty("t") === false))
  {
    echo "Invalid boolean value\n";
    return false;
  }

  $sl = new TElStringList();
  $sl->CaseSensitive = true;
  if (!($sl->CaseSensitive === true))
  {
    echo "Invalid boolean value\n";
    return false;
  }

  $sl->CaseSensitive = false;
  if (!($sl->CaseSensitive === false))
  {
    echo "Invalid boolean value\n";
    return false;
  }

  return true;
}

// Byte : in, result

function TestByteParameters()
{
  $rdn = new TElRelativeDistinguishedName();
  $rdn->Count = 3;
  $rdn->set_Tags(0, 250);
  $rdn->set_Tags(1, 256);
  $b = 10;
  $rdn->set_Tags(2, $b);
  if (!($rdn->get_Tags(0) === 250) || ($rdn->get_Tags(1) != 0) || ($rdn->get_Tags(2) != 10) || ($b != 10))
  {
    echo "Invalid byte value\n";
    return false;
  }

  return true;
}

// Word : in, out, result

function TestWordParameters()
{
  $Year = 0;
  $Month = 0;
  $Day = 0;
  $Hour = 0; 
  $Minute = 0; 
  $Second = 0; 
  $MilliSecond = 0;
  $dt = SBUtils\DateTimeUtcNow();
  SBStrUtils\DecodeDateTime($dt, $Year, $Month, $Day, $Hour, $Minute, $Second, $MilliSecond);  
  $s = sprintf("%04d-%02d-%02d %02d:%02d:%02d", $Year, $Month, $Day, $Hour, $Minute, $Second);
  if ($dt->format('Y-m-d H:i:s') != $s)
  {
    echo "Invalid word value\n";
    return false;
  }

  $Buf = "";
  SBUtils\SwapUInt16(0x3155, $Buf);
  if (!(SBUtils\GetWordBEFromByteArray($Buf, 0) === 0x3155))
  {
    echo "Invalid word value\n";
    return false;
  }

  return true;
}

// Integer : in, var, result

function TestIntegerParameters()
{
  $Str = SBUtils\BinaryToString("test", 1, 3);
  $Buf = "";
  $Size = 0;
  SBUtils\StringToBinary($Str, $Buf, $Size);
  $Buf = str_repeat(' ', $Size);
  SBUtils\StringToBinary($Str, $Buf, $Size);
  if ($Buf != substr("test", 1, 3) || !($Size === 3) || !(SBUtils\ConstLength($Buf) === 3))
  {
    echo "Invalid integer value\n";
    return false;
  }

  $val = SBUtils\SwapUInt32(0x003377AA);
  if ($val != (integer)0xAA773300)
  {
    echo "Invalid integer value\n";
    return false;
  }

  return true;
}

// Int64

function TestInt64Parameters()
{
  SBUtils\SwapInt64(0x0011223344556677);
  return true;
}

// Double : in, result

function TestDoubleParameters()
{
  $d = SBBZip2Utils\IfThenDouble(true, 0.11111111, 0);
  if (!($d === 0.11111111))
  {
    echo "Invalid double value\n";
    return false;
  }   

  return true;
}

// DateTime : in, var, result

function TestDateTimeParameters()
{
  // echo SBUtils\EmptyDateTime()->format(DATE_W3C) . "\n";
  if (!SBUtils\IsEmptyDateTime(SBUtils\EmptyDateTime()))
  {
    echo "Invalid datetime value\n";
    return false;
  }

  $dt0 = DateTime::createFromFormat("U", 1);
  $dt = new DateTime();
  if (!SBUtils\RFC822TimeStringToUniversalTime(SBUtils\UniversalDateTimeToRFC822DateTimeString($dt0), $dt))
  {
    echo "Invalid datetime value\n";
    return false;
  }   

  if ($dt != $dt0)
  {
    echo "Invalid datetime value\n";
    return false;
  }   

  return true;
}

// Enum : in, result

function TestEnumParameters()
{
  $sl = new TElStringlist();
  $sl->Duplicates = TDuplicates::dupError;
  if ($sl->Duplicates != TDuplicates::dupError)
  {
    echo "Invalid enum value\n";
    return false;
  }   

  return true;
}

// Flags : in, result

function TestFlagsParameters()
{
  $ext = new TElCertificateExtensions();
  $ext->Included = TSBCertificateExtensions::ceAuthorityKeyIdentifier | TSBCertificateExtensions::ceKeyUsage;
  if (($ext->Included != 5) || (($ext->Included & TSBCertificateExtensions::ceAuthorityKeyIdentifier) == 0) || (($ext->Included & TSBCertificateExtensions::ceKeyUsage) == 0))
  {
    echo "Invalid flags value\n";
    return false;
  }   

  return true;
}

// Char : in, result

function TestCharParameters()
{
  $sl = new TElStringlist();
  $sl->Delimiter = '%';
  if ($sl->Delimiter != '%')
  {
    echo "Invalid char value\n";
    return false;
  }   

  if (SBStrUtils\StringLastIndexOf("test", "e") != 2)
  {
    echo "Invalid char value\n";
    return false;
  }   

  return true;
}

// WideChar : in, var

function TestWideCharParameters()
{
  if (SBStrUtils\StringIndexOfU("test", "e") != 2)
  {
    echo "Invalid widechar value\n";
    return false;
  }   

  try {
    // two UTF-8 chars shouldn't be allowed
    SBStrUtils\StringIndexOfU("test", "es"); 
    echo "Invalid widechar value\n";
    return false;
  } catch(SBException $e) {
    // echo $e->getMessage() . "\n";
  }

  if (SBStrUtils\StringIndexOfU("test\xC3\xA75", "\xC3\xA7") != 5)
  {
    echo "Invalid widechar value\n";
    return false;
  }   

  $w = "\xC3\xA7";
  SBChSUnicode\WideUpperCase($w);
  if ($w != "\xC3\x87")
  {
    echo "Invalid widechar value\n";
    return false;
  }   

  return true;
}

// String : in, var, result

function TestStringParameters()
{  
  $Protocol = "";
  $Username = ""; 
  $Password = ""; 
  $Host = "";
  $Port = 0;
  $Path = ""; 
  $Anchor = ""; 
  $Parameters = "";
  SBStrUtils\ParseURL("http://test.com:80/path/test.html?a=b&c=d#anchor", true, $Protocol, $Username, $Password, $Host, $Port, $Path, $Anchor, $Parameters);
  if (($Protocol != "http") || ($Username != "") || ($Password != "") || ($Host != "test.com") || ($Port != 80) || ($Path != "/path/test.html") || ($Anchor != "anchor") || ($Parameters != "?a=b&c=d"))
  {
    echo "Invalid string value\n";
    return false;
  }

  $Protocol = $Protocol . "a";
  $Username = $Username . "a";
  SBStrUtils\ParseURL("http://test.com:80/path/test.html?a=b&c=d#anchor", true, $Protocol, $Username, $Password, $Host, $Port, $Path, $Anchor, $Parameters);
  if (($Protocol != "http") || ($Username != "") || ($Password != "") || ($Host != "test.com") || ($Port != 80) || ($Path != "/path/test.html") || ($Anchor != "anchor") || ($Parameters != "?a=b&c=d"))
  {
    echo "Invalid string value\n";
    return false;
  }

  if (SBStrUtils\PrefixString("test", 3, "A") != "AAAtest")
  {
    echo "Invalid string value\n";
    return false;
  }

  if (SBStrUtils\StringRemove("t", 1, 1) != "")
  {
    echo "Invalid string value\n";
    return false;
  }

  return true;
}

// WideString : in, result

function TestWideStringParameters()
{  
  if (SBStrUtils\WideStringRemove("test\xC3\xA7\xC3\x87", 5, 1) != "test\xC3\x87")
  {
    echo "Invalid widestring value\n";
    return false;
  }

  if (SBUtils\WideBytesOf("t\xC3\xA7") != "t\x00\xE7\x00")
  {
    echo "Invalid widestring value\n";
    return false;
  }

  return true;
}

// ByteArray : in, var, result

function TestByteArrayParameters()
{  
  // test StringOfBytes/BytesOfString functions
  if (SBUtils\StringOfBytes(array()) != "")
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  if (SBUtils\StringOfBytes(array(32, 65)) != " A")
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  if (!(SBUtils\BytesOfString("") === array()))
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  if (!(SBUtils\BytesOfString("ABC") === array(65, 66, 67)))
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  // main test
  if (SBUtils\SubArray("A B", 0, 2) != "A ")
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  if (SBUtils\SubArray(array(65, 32, 66), 1, 2) != " B")
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  if ((SBUtils\SubArray(array(), 0, 0) != "") || (SBUtils\SubArray(NULL, 0, 0) != ""))
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  $Buf = "";
  if ((SBStrUtils\ConvertUTF16toUTF8("t\xC3\xA7", $Buf, ConversionFlags::strictConversion, true) != ConversionResult::conversionOK) ||
      ($Buf != "\xEF\xBB\xBFt\xC3\xA7"))
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  $Buf = array();
  if ((SBStrUtils\ConvertUTF16toUTF8("t\xC3\xA7", $Buf, ConversionFlags::strictConversion, true) != ConversionResult::conversionOK) ||
      ($Buf != array(0xEF, 0xBB, 0xBF, 116, 0xC3, 0xA7)))
  {
    echo "Invalid bytearray value\n";
    return false;
  }

  return true;
}

// IntegerArray

function TestIntegerArrayParameters()
{  
  return true;
}

// StringArray/TStringList : in, result

function TestStringArrayParameters()
{  
  $sl = SBStrUtils\StringSplit("A B C", " ");
  if ((get_class($sl) != "TStringList") || ($sl->Count != 3) || 
      ($sl->get_Strings(0) != "A") || ($sl->get_Strings(1) != "B") || ($sl->get_Strings(2) != "C"))
  {
    echo "Invalid string array value\n";
    return false;
  }

  if (SBStrUtils\SBConcatAnsiStrings($sl) != "ABC")
  {
    echo "Invalid string array value\n";
    return false;
  }

  return true;
}

// Record

function TestRecordParameters()
{  
  return true;
}

// Object

function TestObjectParameters()
{  
  // TElStream is alias of TStream
  $st = new TElStream();
  if ((TElStream::ClassName() != "TObject") || 
      ($st->ClassName_Inst() != "TStream"))
  {
    echo "Invalid object value\n";
    return false;
  }

  $o = new TObject();
  $o->Free();

  $Doc = new TElOfficeDocument(NULL);
  if ($Doc->BinaryDocument != NULL)
  {
    echo "Invalid object value (not NULL)\n";
    return false;
  }

  return true;
}

// Pointer

function TestPointerParameters()
{  
  $p = new TSBPointer();
  $p->setData(NULL);
  if (!$p->isNULL())
  {
    echo "Invalid pointer value\n";
    return false;
  }

  return true;
}

// Formal

function TestFormalParameters()
{  
  $ms = new TElMemoryStream();
  $Buf = "test string";
  $ms->Write($Buf, strlen($Buf));
  $Buf = str_repeat(" ", 10);
  $ms->Position = 2;
  $len = $ms->Read($Buf, strlen($Buf));
  if (strlen($Buf) > $len)
    $Buf = substr($Buf, 0, $len);

  if ($Buf != "st string")
  {
    echo "Invalid formal value\n";
    return false;
  }

  $ms->Clear();
  $Buf = array(0, 1, 2, 3, 4, 5, 6, 7);
  $ms->Write($Buf, count($Buf));
  $ms->Write(NULL, 0); // test writting null
  $Buf = array_fill(0, 10, 'aa');
  $ms->Position = 3;
  $len = $ms->Read($Buf, count($Buf));
  if (count($Buf) > $len)
    $Buf = array_slice($Buf, 0, $len);

  if ($Buf != array(3, 4, 5, 6, 7))
  {
    echo "Invalid formal value\n";
    return false;
  }

  $ms->Clear();
  $p = new TSBPointer();
  $p->setData("test test");
  $ms->Write($p, $p->getLength());
  $p->setLength(0);
  $p->setLength(10);
  $ms->Position = 1;
  $len = $ms->Read($p, $p->getLength());
  $p->setLength($len);
  if ($p->getData() != "est test")
  {
    echo "Invalid formal value\n";
    return false;
  }

  return true;
}

// Pointer to record

function TestRecordPointerParameters()
{  
  return true;
}

// Cast Objects

function TestCastObjects()
{  
  $ms = new TElMemoryStream();
  $st = $ms->CastTo("TStream");
  if ((get_class($st) != "TStream") || (get_class($st->CastTo()) != "TMemoryStream"))
  {
     echo "Invalid object cast\n";
     return false;
  }

  if ($st != $ms)
  {
     echo "Invalid object compare\n";
     return false;
  }

  // testing register and unregister handlers
  SBPDF\UnregisterSecurityHandler(TElPDFPublicKeySecurityHandler::ClassType());
  SBPDF\UnregisterSecurityHandler(TElPDFAdvancedPublicKeySecurityHandler::ClassType());
  SBPDF\RegisterSecurityHandler(TElPDFAdvancedPublicKeySecurityHandler::ClassType());
  SBPDF\RegisterSecurityHandler(TElPDFPublicKeySecurityHandler::ClassType());

  return true;
}

// Callback procs

// Events

function DoFormatElement($Sender, $Element, $Level, $Path, &$StartTagWhitespace, &$EndTagWhitespace)
{
  // var_dump(func_get_args());
  if (($Level != 1) || ($Path != '/root') || ($StartTagWhitespace != '') || 
      ($Element->NodeName != 'dummy') || ($Sender->castTo()->ClassName_Inst() != "TElXMLFormatter"))
  {
     echo "Invalid input in DoFormatElement event handler\n";
     $OK = false;
  }

  $EndTagWhitespace = "\n\t";

  return "s";
}

class TFormatTextClass
{
  public $Text = "";

  public function DoFormatText($Sender, &$Text, $TextType, $Level, $Path)
  {
    if (($Level != 1) || ($Path != '/root') || ($Text != 'TEXT') || ($TextType != 'TElXMLTextType::ttNormal'))
    {
      echo "Invalid input in DoFormatText event handler\n";
      $OK = false;
    }

    $Text = $this->Text;
  }
}

function TestEvents()
{  
  $doc = new TElXMLDOMDocument();
  $root = $doc->CreateElement("root");
  $doc->AppendChild($root);
  $el = $doc->CreateElement("dummy");
  $formatter = new TElXMLFormatter();
  $formatter->OnFormatElement = "DoFormatElement";
  $formatter->AppendElement($doc->DocumentElement, $el);
  if (($root->TextContent != "\n\t") || ($formatter->OnFormatElement != "DoFormatElement"))
  {
     echo "Invalid event result\n";
     return false;
  }

  $root->TextContent = '';
  $ft = new TFormatTextClass();
  $ft->Text = "Text";
  $formatter->OnFormatText= array($ft, "DoFormatText");
  $formatter->AppendText($root, "TEXT", TElXMLTextType::ttNormal);
  if ($root->TextContent != "Text")
  {
     echo "Invalid event result\n";
     return false;
  }

  return true;
}


error_reporting(E_ALL);
date_default_timezone_set("UTC");

if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) 
{
	echo "SecureBlackbox extension NOT available\n"; 
	die;
}

echo "SecureBlackbox v" . SBUtils\SBB_VERSION_NUMBER . " Tests\n";
echo "PHP v" . PHP_VERSION . "\n";

try {
  SBUtils\SetLicenseKey("AABB");
  echo "Exception not thrown: SetLicenseKey\n";
  $OK = false;
} catch(SBException $e) {
  // echo 'Message: ' . $e->getMessage() . "\n";
  if (($e->getErrorCode() != SBUtils\ERROR_LICENSE_KEY_INVALID) || ($e->getCode() != 2) || ($e->getErrorName() != "EElLicenseError") || ($e->getErrorMessage() != SBUtils\SBadLicenseKeyFormat))
  {
    echo "Error code: {$e->getErrorCode()}, code: {$e->getCode()}, error name: {$e->getErrorName}\n";
    echo "Error message: {$e->getErrorMessage()}\n";
    echo "Invalid license key exception\n";
    $OK = false;
  }
}

try {

  // Test Parameters:

  $OK = TestBooleanParameters() && $OK;
  $OK = TestByteParameters() && $OK;
  $OK = TestWordParameters() && $OK;
  $OK = TestIntegerParameters() && $OK;
  $OK = TestInt64Parameters() && $OK;
  $OK = TestDoubleParameters() && $OK;
  $OK = TestDateTimeParameters() && $OK;
  $OK = TestEnumParameters() && $OK;
  $OK = TestFlagsParameters() && $OK;
  $OK = TestCharParameters() && $OK;
  $OK = TestWideCharParameters() && $OK;
  $OK = TestStringParameters() && $OK;
  $OK = TestWideStringParameters() && $OK;
  $OK = TestByteArrayParameters() && $OK;
  $OK = TestIntegerArrayParameters() && $OK;
  $OK = TestStringArrayParameters() && $OK;
  $OK = TestRecordParameters() && $OK;
  $OK = TestObjectParameters() && $OK;
  $OK = TestPointerParameters() && $OK;
  $OK = TestFormalParameters() && $OK;
  $OK = TestRecordPointerParameters() && $OK;
  $OK = TestCastObjects() && $OK;
  $OK = TestEvents() && $OK;

} catch(Exception $e) {
  echo 'Message: ' .$e->getMessage() . "\n";
  $OK = false;
}

  echo "\n";
  if ($OK)
    echo "Tests PASSED\n\n";
  else
  {
    echo "Tests FAILED\n";
    trigger_error("Tests FAILED", E_USER_ERROR);
  }

?>