<?php

    // The user is redirected here by the script's main page. 
    // 
    // The script creates a work directory for the session (<script_root>/work/<session_id>),
    // and copies the original document there. It then pre-signs the document and generates
    // an applet page basing on the asynchronous state it received as a result of the 
    // pre-signing operation.
    //
    // Please ensure that you have copied both applet binaries to the directory of this script:
    //   com.secureblackbox.dc.jar  
    //   com.secureblackbox.dc.applet.jar

    error_reporting(E_ALL);
    date_default_timezone_set("UTC");
    
    if (!isset($_GET["sessionid"])) {
        print "No session information found. Please start again from <a href='../'>the main page</a>.";
	return; 
    }

    $session_id = $_GET["sessionid"];

    // creating per-session temporary directory for the signing operation
    $path = "../work/" . $session_id;

    if (is_dir($path) === false) {
        mkdir($path);
    }

    // copying the source file there
    copy("../source/source.pdf", $path . "/presigned.pdf");

    // proceeding to the pre-signing operation
    if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) {
        print "SecureBlackbox extension is NOT available";
        die;
    }

    // setting SecureBlackbox license key
    try {
        if (!SBUtils\GetLicense()) {

            #error Please pick the evaluation license key from <SecureBlackbox>\LicenseKey.txt file and place it in "sbb.license_key" php.ini directive or here. If the evaluation key expires, you can request an extension using the form on https://www.eldos.com/sbb/keyreq/
            SBUtils\SetLicenseKey("");
        }
    } catch (SBException $e) {
        print "<p style='color:red'>Setting SBB License Key failed with message: <br/>" . $e->getErrorMessage() . "</p>";
        die;
    }
        

    // opening and pre-signing the document
     
    // note that while you are OK with relative paths
    // in the code above, you need to pass absolute paths to SBB components

    $cwd = getcwd();
    $workdir = $cwd . "/../work/" . $session_id;

    $error_happened = false;

    $pdfStream = new TFileStream($workdir . "/presigned.pdf", TFileMode::fmOpenReadWrite);
    try {
        $pdfDocument = new TElPDFDocument(null);
        $pdfDocument->Open($pdfStream);
                    
        $publicKeyHandler = new TElPDFPublicKeySecurityHandler(null);
        $index = $pdfDocument->AddSignature();
        $sig = $pdfDocument->get_Signatures($index);
        $sig->Handler = $publicKeyHandler;
        $sig->AuthorName = "PHP PDF signer demo";
        $sig->Reason = "Signing test";
                    
        $dt = SBUtils\DateTimeUtcNow();
        $sig->SigningTime = $dt;
        $sig->Invisible = false;
        $sig->SignatureType = TSBPDFSignatureType::stDocument;
	$sig->ExtraSpace = 16384;
                    
        //$certStorage = new TElMemoryCertStorage(null);
        //$certStorage->Add($cert, true);
                    
        //$publicKeyHandler->CertStorage = $certStorage;
        $publicKeyHandler->SignatureType = TSBPDFPublicKeySignatureType::pstPKCS7SHA1;
        // see the full list of signature types at https://www.eldos.com/documentation/sbb/documentation/ref_cl_pdfpublickeysecurityhandler_prp_signaturetype.html
        $publicKeyHandler->CustomName = "Adobe.PPKMS";
                    
        //$pdfDocument->Close(true);
        $asyncState = $pdfDocument->InitiateAsyncOperation();

        $stateStream = new TMemoryStream();

        $asyncState->SaveToStream($stateStream, new TElDCXMLEncoding());

        $stateStream->Position = 0;
        $stateString = SBStrUtils\UTF8ToStr(SBStreams\StreamReadAll($stateStream));

        $stateStringBase64 = base64_encode($stateString);

    } catch(SBException $e) {
        $error_happened = true;
        $error_details = "PDF signing failed with message: " . $e->getErrorMessage();
    }
    $pdfStream->Free();
            
    if ($error_happened) {
                
        print "Error happened: <br/>" . $error_details;
         
        return;
    } 
?>

<html>
<head>
  <title>EldoS PDF Distributed Signer demo</title>
  <style type="text/css">
  .textheader {
    font-family: Arial;
    font-size: 16;
    font-weight: bold;
  }
  .textnormal {
    font-family: Arial;
    font-size: 12;
  }
  </style>
</head>
<body>
  <div align="center">
  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">
    <tr height="*"></tr>
    <tr height="400">
      <td width="600" valign="top">
        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">
          <tr height="50">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textheader">EldoS SecureBlackbox Distributed PDF Signer demo</div>
            </td>
          </tr>
          <tr height="70">
            <td width="100%" height="*" align="center" valign="center" class="textnormal">
              <div align="center"> 
                This is a first step of the distributed signing protocol. Below you will see a Java applet 
                (shipped with SecureBlackbox), which asks you for the location of your signing certificate.
                You are offered to specify a certificate residing in a system store, on a PKCS#11 
                device, or in a file.
                <br /><br />
                On this stage the source document has already been pre-signed, and the pre-signed copy was copied to
                a local (to the web server) temporary directory with a temporary unique ID, which is '<?php print $session_id; ?>' for this script instance. It will be accessed again by the signing finalization
                script triggered by the applet when you click its 'Finish' button.
              </div>
            </td>
          </tr>
          <tr height="*">
            <td width="100%" height="*" align="center" class="textnormal">
              <applet archive="com.secureblackbox.dc.jar, com.secureblackbox.dc.applet.jar" 
                code="com.secureblackbox.dc.applet.ElDCServerApplet" width=500 height=240>
                <param name="Color" value="#FFFFFF" />
                <param name="DataURL" value="../finalize/" />
                <param name="GoURL" value="../result/" />
                <param name="Data" value="<?php print $stateStringBase64; ?>" />
                <param name="SessionID" value="<?php print $session_id; ?>" />
              </applet>
            </td>
          </tr>
          <tr height="20">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>
            </td>
          </tr>
        </table>
      </td>
    </tr>
    <tr height="*"></tr>
  </table>
  </div>
</body>
</html>