<?php 
    date_default_timezone_set("UTC");

    SBPDF\UnregisterSecurityHandler(TElPDFPublicKeySecurityHandler::ClassType());
    SBPDF\UnregisterSecurityHandler(TElPDFAdvancedPublicKeySecurityHandler::ClassType());
    SBPDF\RegisterSecurityHandler(TElPDFAdvancedPublicKeySecurityHandler::ClassType());
    SBPDF\RegisterSecurityHandler(TElPDFPublicKeySecurityHandler::ClassType());

    $pdf = new TElPDFDocument(NULL);
    $revinfo = new TElPDFPublicKeyRevocationInfo();
    $filename = "";
    $tempname = "";

    function ExtractRefInfo()
    {
        global $pdf;
        global $revinfo;

        if ($pdf != NULL)
        {
            $revinfo->Clear();

            for ($i = 0; $i <= $pdf->SignatureCount - 1; $i++)
            {
                if ($pdf->get_Signatures($i)->get_Handler()->ClassName_Inst() == 'TElPDFAdvancedPublicKeySecurityHandler')
                {
                    $handler = $pdf->get_Signatures($i)->get_Handler();
                    $handler->CastTo()->get_CMS()->ExtractAllCertificates($revinfo->Certificates);

                    for ($k = 0; $k <= $handler->CastTo()->get_CMS()->get_CRLs()->Count - 1; $k++)
                    {
                        $index = $revinfo->AddCRL();
                        $revinfo->get_CRLs($index)->Assign($handler->get_CMS()->get_CRLs()->get_CRLs($k));
                    }

                    $revinfo->Assign($handler->CastTo()->get_DSSRevocationInfo(), false);
                    $revinfo->Assign($handler->CastTo()->get_RevocationInfo(), false);
                }
            }
        }
    }

    function ShowForm()
    {
        global $pdf;
        global $revinfo;
        global $tempname;
        global $filename;

        echo '<html>';
        echo '<head>';
        echo '  <title>EldoS PAdES demo</title>';
        echo '  <style type="text/css">';
        echo '  .textheader {';
        echo '    font-family: Arial;';
        echo '    font-size: 16;';
        echo '    font-weight: bold;';
        echo '  }';
        echo '  .textnormal {';
        echo '    font-family: Arial;';
        echo '    font-size: 12;';
        echo '  }';
        echo '  </style>';
        echo '</head>';
        echo '<body>';
        echo '  <div align="center">';
        echo '  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">';
        echo '    <tr height="*"></tr>';
        echo '    <tr height="400">';
        echo '      <td width="600" valign="top">';
        echo '        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">';
        echo '          <tr height="50">';
        echo '            <td width="100%" valign="center" bgcolor="#e6e6e6">';
        echo '              <div align="center" class="textheader">EldoS SecureBlackbox PAdES demo</div>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="50">';
        echo '            <td width="100%" height="*" align="center" valign="center" class="textnormal">';
        echo '              <div align="center"> This sample illustrates the use of SecureBlackbox PAdES components. </div>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="*">';
        echo '            <td width="100%" height="*">';
        echo '              <form action="PAdES.php" method="post" enctype="multipart/form-data">';
        echo '                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">';
        echo '                  <tr height="30" valign="bottom">';
        echo '                    <td width="30%" align="left"> <span class="mtx4">Document properties:</span> </td>';
        echo '                    <td width="10"></td>';
        echo '                    <td width="*" align="right"></td>';
        echo '                  </tr>';
        echo '                  <tr height="70" valign="bottom">';
        echo '                    <td colspan="3" align="left">';
        echo '                      <table border class="textnormal">';
        echo '                       <tr> <th width="300"> Property </th>  <th width="300"> Value </th> </tr>';
        echo '                       <tr> <td> Filename </td>  <td> ' . $filename . ' </td> </tr>';
        echo '                       <tr> <td> Pages </td>  <td> ' . $pdf->PageInfoCount . ' </td> </tr>';
        echo '                       <tr> <td> Attachments </td>  <td> ' . $pdf->AttachedFileCount . ' </td> </tr>';

        if ($pdf->Signed)
        {
            echo '                       <tr> <td> Signed </td>  <td> yes </td> </tr>';
        }
        else
        {
            echo '                       <tr> <td> Signed </td>  <td> no </td> </tr>';
        }

        echo '                       <tr> <td> Empty signature fields </td>  <td> ' . $pdf->EmptySignatureFieldCount . ' </td> </tr>';
        echo '                      </table>';
        echo '                    </td>';
        echo '                  </tr>';

        if ($pdf->SignatureCount > 0)
        {
            echo '                  <tr height="30" valign="bottom">';
            echo '                    <td width="30%" align="left"> <span class="mtx4">Signatures:</span> </td>';
            echo '                    <td width="10"></td>';
            echo '                    <td width="30" align="right"></td>';
            echo '                  </tr>';
            echo '                  <tr height="30" valign="bottom">';
            echo '                    <td colspan="3" align="left">';
            echo '                      <table border class="textnormal">';
            echo '                       <tr> <th> Type </th>  <th> Name </th> <th> Author </th> <th> Signing time </th> <th> Timestamped </th> <th> Validity </th> </tr>';

            for ($i = 0; $i <= $pdf->SignatureCount - 1; $i++)
            {
                $S = '                       <tr> <td>';
                $T = '';

                $sig = $pdf->get_Signatures($i);
                $handler = $sig->get_Handler();
                $advance = false;
                if ($handler->ClassName_Inst() == 'TElPDFAdvancedPublicKeySecurityHandler')
                {
                    $advance = true;
                    if ($handler->CastTo()->get_PAdESSignatureType() == TSBPAdESSignatureType::pastBasic)
                    {
                        $S = $S . 'Basic';
                    }
                    else
                    if ($handler->CastTo()->get_PAdESSignatureType() == TSBPAdESSignatureType::pastEnhanced)
                    {
                        $S = $S . 'Enhanced (long-term)';
                    }
                    else
                    if ($handler->CastTo()->get_PAdESSignatureType() == TSBPAdESSignatureType::pastDocumentTimestamp)
                    {
                        $S = $S . 'DocumentTimestamp';
                    }
                    else
                    {
                        $S = $S . 'Unknown';
                    }
                }
                else
                if ($handler->ClassName_Inst() == 'TElPDFPublicKeySecurityHandler')
                {
                    $S = $S . 'Standard';
                }
                else
                {
                    $S = $S . 'Unknown';
                }

                $S = $S . '</td> <td> ' . $sig->SignatureName . '</td>';

                if ($advance)
                {
                    $S = $S . '<td> Issure: ' . $handler->CastTo()->get_CMS()->get_Signatures(0)->get_Signer()->get_Issuer()->SaveToDNString() . 
                              ', S/N: ' . SBUtils\BinaryToString($handler->CastTo()->get_CMS()->get_Signatures(0)->get_Signer()->get_SerialNumber()) . '</td> ';

                    if ($handler->CastTo()->get_ValidationDetails() == TSBCMSAdvancedSignatureValidity::casvUnknown)
                    {
                        try
                        {
                            $handler->CastTo()->set_ValidationMoment(SBUtils\EmptyDateTime());
                            $sig->Validate();

                            if (!$sig->IsDocumentSigned())
                            {
                                $T = 'Signature does not cover the entire document';
                            }
                        }
                        catch(SBException $e) 
                        {
                            $T = $e->getMessage();
                        }
                    }

                    if ($handler->CastTo()->get_TimestampCount() > 0)
                    {
                        $S = $S . '<td> ' . $handler->CastTo()->get_Timestamps(0)->get_Time()->format('d-m-Y H:i:s') . '</td> <td> yes </td>';
                    }
                    else
                    if ($handler->CastTo()->get_PAdESSignatureType() == TSBPAdESSignatureType::pastDocumentTimestamp)
                    {
                        $S = $S . '<td> ' . $handler->get_DocumentTimestamp()->get_Time()->format('d-m-Y H:i:s') . '</td> <td> yes </td>';
                    }
                    else
                    {
                        $S = $S . '<td> ' . $sig->SigningTime->format('d-m-Y H:i:s') . '</td> <td> no </td>';
                    }

                    
                    switch ($handler->CastTo()->get_ValidationDetails()) {
                        case TSBCMSAdvancedSignatureValidity::casvValid : $V = 'Valid'; break;
                        case TSBCMSAdvancedSignatureValidity::casvSignatureCorrupted : $V = 'Signature corrupted'; break;
                        case TSBCMSAdvancedSignatureValidity::casvSignerNotFound : $V = 'Signer not found'; break;
                        case TSBCMSAdvancedSignatureValidity::casvIncompleteChain : $V = 'Incomplete chain'; break;
                        case TSBCMSAdvancedSignatureValidity::casvBadCountersignature : $V = 'Bad countersignature'; break;
                        case TSBCMSAdvancedSignatureValidity::casvBadTimestamp : $V = 'Bad timestamp'; break;
                        case TSBCMSAdvancedSignatureValidity::casvCertificateExpired : $V = 'Certificate expired'; break;
                        case TSBCMSAdvancedSignatureValidity::casvCertificateRevoked : $V = 'Certificate revoked'; break;
                        case TSBCMSAdvancedSignatureValidity::casvCertificateCorrupted : $V = 'Certificate corrupted'; break;
                        case TSBCMSAdvancedSignatureValidity::casvUntrustedCA : $V = 'Untrusted CA'; break;
                        case TSBCMSAdvancedSignatureValidity::casvRevInfoNotFound : $V = 'Revocation information not found'; break;
                        case TSBCMSAdvancedSignatureValidity::casvTimestampInfoNotFound : $V = 'Timestamp information not found'; break;
                        case TSBCMSAdvancedSignatureValidity::casvFailure : $V = 'General failure'; break;
                        case TSBCMSAdvancedSignatureValidity::casvCertificateMalformed : $V = 'Certificate malformed'; break;
                        case TSBCMSAdvancedSignatureValidity::casvUnknown : $V = 'Unknown'; break;
                        case TSBCMSAdvancedSignatureValidity::casvChainValidationFailed : $V = 'Chain validation failed'; break;
                        default: $V = '';
                    }

                    if ((strlen($V) > 0) and (strlen($T) > 0))
                    {
                        $S = $S . '<td>' . $V . ', ' . $T . '</td>';
                    }
                    else
                    {
                        $S = $S . '<td>' . $V . $T . '</td>';
                    }
                }
                else
                {
                    $S = $S . '<td> ' . $sig->AuthorName . '</td> <td> ' . $sig->SigningTime->format('d-m-Y H:i:s') . '</td> <td> N/A </td> <td> N/A </td> </tr>';
                }

                echo $S;
            }

            echo '                      </table>';
            echo '                    </td>';
            echo '                  </tr>';
        }
        else
        {
            echo '                  <tr height="0" valign="bottom">';
            echo '                    <td colspan="3" align="left"> <input type="hidden" name="pdffile" value="' . $tempname . '" size="30" /> </td>';
            echo '                  </tr>';
            echo '                  <tr height="0" valign="bottom">';
            echo '                    <td colspan="3" align="left"> <input type="hidden" name="filename" value="' . $filename . '" size="30" /> </td>';
            echo '                  </tr>';
            echo '                  <tr height="60" valign="bottom">';
            echo '                    <td colspan="3" align="left"> <label>Certificate file: <input type="file" name="certfile" value="" size="30" /> </label> </td>';
            echo '                  </tr>';
            echo '                  <tr height="35" valign="bottom">';
            echo '                    <td colspan="3" align="left"> <label>Password: <input type="password" name="password" value="password" size="30" /> </label> </td>';
            echo '                  </tr>';
            echo '                  <tr height="30">';
            echo '                    <td width="20%" align="left"> <label><input type="checkbox" name="vissig" value="yes"/> Visible signature</label> </td>';
            echo '                    <td width="10"></td>';
            echo '                    <td width="*" align="left"> <label><input type="checkbox" name="advance" value="yes"/> Create advanced (PAdES) signature</label> <td>';
            echo '                  </tr>';
            echo '                  <tr height="30">';
            echo '                    <td colspan="3" align="left"> <label><input type="checkbox" name="autocol" value="yes"/> Automatically collect missing revocation information (CRL\'s, OCSP statuses)</label> <td>';
            echo '                  </tr>';
            echo '                  <tr height="30">';
            echo '                    <td colspan="3" align="left"> <label><input type="checkbox" name="ignore" value="yes"/> Ignore chain validation errors </label> <td>';
            echo '                  </tr>';
            echo '                  <tr height="40" valign="bottom">';
            echo '                    <td colspan="3" align="left"> <label><input type="checkbox" name="timestamp" value="yes"/> Request a timestamp from TSA server </label> <td>';
            echo '                  </tr>';
            echo '                  <tr height="30">';
            echo '                    <td colspan="3" align="left"> <input type="text" name="host" value="http://" size="50"/> <td>';
            echo '                  </tr>';
            echo '                  <tr height="45" valign="center">';
            echo '                    <td colspan="3" align="center"> <input type="submit" name="sign" value="Add signature"/> </td>';
            echo '                  </tr>';
        }

        if (($revinfo->get_Certificates()->Count > 0) or ($revinfo->CRLCount > 0) or ($revinfo->OCSPResponseCount > 0))
        {
            echo '                  <tr height="30" valign="bottom">';
            echo '                    <td width="30%" align="left"> <span class="mtx4">Revocation information:</span> </td>';
            echo '                    <td width="10"></td>';
            echo '                    <td width="30" align="right"></td>';
            echo '                  </tr>';
            echo '                  <tr height="30" valign="bottom">';
            echo '                    <td colspan="3" align="left">';
            echo '                      <table border class="textnormal">';
            echo '                       <tr> <th width="100"> Type </th>  <th width="500"> Details </th> </tr>';

            for ($i = 0; $i <= $revinfo->get_Certificates()->Count - 1; $i++)
            {
                echo '                       <tr> <td> Certificate </td> <td> ' .
                     $revinfo->get_Certificates()->get_Certificates($i)->get_SubjectRDN()->SaveToDNString() . '</td>';
            }
            for ($i = 0; $i <= $revinfo->CRLCount - 1; $i++)
            {
                echo '                       <tr> <td> CRL </td> <td> Issuer: ' .
                     $revinfo->get_CRLs($i)->get_Issuer()->SaveToDNString() . ' time: ' .
                     $revinfo->get_CRLs($i)->get_ThisUpdate()->format('d-m-Y H:i:s') . ' </td>';
            }
            for ($i = 0; $i <= $revinfo->OCSPResponseCount - 1; $i++)
            {
                echo '                       <tr> <td> OCSP response </td> <td> No details </td>';
            }

            echo '                      </table>';
            echo '                    </td>';
            echo '                  </tr>';
        }

        echo '                  <tr height="30" valign="bottom">';
        echo '                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>';
        echo '                  </tr>';
        echo '                </table>';
        echo '              </form>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="20">';
        echo '            <td width="100%" valign="center" bgcolor="#e6e6e6">';
        echo '              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>';
        echo '            </td>';
        echo '          </tr>';
        echo '        </table>';
        echo '      </td>';
        echo '    </tr>';
        echo '    <tr height="*"></tr>';
        echo '  </table>';
        echo '  </div>';
        echo '</body>';
        echo '</html>';
    }

    if (isset($_POST["sign"])) 
    {
        $pdffile = $_POST["pdffile"];
        $filename = $_POST["filename"];
        $certfile = $_FILES["certfile"]["tmp_name"];
        $password = $_POST["password"];
        $vissig = (isset($_POST['vissig']) && $_POST['vissig'] == 'yes');
        $advance = (isset($_POST['advance']) && $_POST['advance'] == 'yes');
        $timestamp = (isset($_POST['timestamp']) && $_POST['timestamp'] == 'yes');
        $host = $_POST["host"];
        $autocol = (isset($_POST['autocol']) && $_POST['autocol'] == 'yes');
        $ignore = (isset($_POST['ignore']) && $_POST['ignore'] == 'yes');

        if (strlen($certfile) > 0)
        {
            try
            {
                $cert = new TElX509Certificate(NULL);
                $r = $cert->LoadFromFileAuto($certfile, $password);
                if ($r != 0)
                {
                    print 'Failed to load certificate, error ' . $r;
                    return;
                }
                if (!$cert->get_PrivateKeyExists())
                {
                    print 'The provided certificate does not have an associated private key ';
                    return;
                }

                $pdfstream = new TMemoryStream;

                $pdfstream->LoadFromFile($pdffile);

                $pdf->set_OwnActivatedSecurityHandlers(true);
                $pdf->Open($pdfstream);

                $index = $pdf->AddSignature();
                $sig = $pdf->get_Signatures($index);

                $certstorage = new TElMemoryCertStorage(NULL);
                $certstorage->Clear();
                $certstorage->Add($cert, true);
                $handler = new TElPDFAdvancedPublicKeySecurityHandler(NULL);
                $handler->set_CertStorage($certstorage);
                if ($advance)
                {
                    $handler->set_PAdESSignatureType(TSBPAdESSignatureType::pastEnhanced);
                }
                else
                {
                    $handler->set_PAdESSignatureType(TSBPAdESSignatureType::pastBasic);
                }
                $handler->set_CustomName('Adobe.PPKMS'); // article: http://www.eldos.com/security/articles/2992.php

                $http = new TElHTTPSClient(NULL);
                $tsp = new TElHTTPTSPClient(NULL);
                if ($timestamp)
                {
                    $tsp->set_HTTPClient($http);
                    $tsp->set_URL($host);
                    $tsp->set_HashAlgorithm(SBConstants\SB_ALGORITHM_DGST_SHA1);
                    $handler->set_TSPClient($tsp);
                }
                else
                {
                    $handler->set_TSPClient(NULL);
                }
                $handler->set_AutoCollectRevocationInfo($autocol);
                $handler->set_IgnoreChainValidationErrors($ignore);

                $sig->Handler = $handler;
                $sig->set_Invisible($vissig);
                $date = new DateTime();
                $sig->set_SigningTime($date);

                $pdf->Close(true);

                $yourfile = basename($filename) . ".tmp";
                $tempname = tempnam(sys_get_temp_dir(), $yourfile);
                $pdfstream->SaveToFile($tempname);

                if (ob_get_level()) 
                {
                    ob_end_clean();
                }

                header('Content-Description: File Transfer');
                header('Content-Type: application/octet-stream');
                header("Content-Disposition: attachment; filename=$filename");
                header('Content-Transfer-Encoding: binary');
                header('Expires: 0');
                header('Cache-Control: must-revalidate');
                header('Pragma: public');
                header('Content-Length: ' . filesize($tempname));
                readfile($tempname);

                unlink($tempname);
                unlink($pdffile);

                return;
                //print "Signing succeeded";
            }
            catch(SBException $e)
            {
                print $e->getMessage();
            }
        }
        else
        {
            print "Certificate file is not provided";
        }
    }

    if (isset($_POST["open"])) 
    {
        if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) 
        {
            print "SecureBlackbox extension is not available, please check that you've set it up correctly";
            die;
        }

        $pdffile = $_FILES["pdffile"]["tmp_name"];
        $filename = $_FILES["pdffile"]["name"];

        if (strlen($pdffile) > 0)
        {
            $tempname = tempnam(sys_get_temp_dir(), $filename);

            if (!copy($pdffile, $tempname)) 
            {
                print "Can not copy $pdffile...\n";
                die;
            }

            $in = new TMemoryStream;

            $in->LoadFromFile($pdffile);

            try
            {
                $pdf->set_OwnActivatedSecurityHandlers(true);
                $pdf->Open($in);

                ExtractRefInfo();

                ShowForm();

                $pdf->Close(false);
            }
            catch(SBException $e) 
            {
                print $e->getMessage();
            }
        }
        else
        {
            print "PDF file is not provided";
        }
    }
?>