<?php
    error_reporting(E_ALL);
    date_default_timezone_set("UTC");
    
    if (isset($_POST["sign"])) {
        if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) {
            print "SecureBlackbox extension NOT available";
            die;
        }
        
        try {
            if (!SBUtils\GetLicense()) {
                #error Please pick the evaluation license key from <SecureBlackbox>\LicenseKey.txt file and place it in "sbb.license_key" php.ini directive or here. If the evaluation key expires, you can request an extension using the form on https://www.eldos.com/sbb/keyreq/
                SBUtils\SetLicenseKey("<enter license key here>");
            }
        } catch (SBException $e) {
            print "<p style='color:red'>Setting SBB License Key failed with message: <br/>" . $e->getErrorMessage() . "</p>";
            die;
        }
        
        $pass = $_POST["pass"];
        $filename = "";
        $certfile = "";
        if ($_FILES["filename"]["error"] == 0) {
            $filename = $_FILES["filename"]["tmp_name"];
        }
        if ($_FILES["certfile"]["error"] == 0) {
            $certfile = $_FILES["certfile"]["tmp_name"];
        }
        
        if ((strlen($filename) > 0) and (strlen($certfile) > 0)) {
            $error_happened = false;
            $error_details = "";
            
            $cert = new TElX509Certificate(null);
            try {
                $res = $cert->LoadFromFileAuto($certfile, $pass);
                if ($res != 0) {
                    $error_happened = true;
                    $cert = null;
                    $error_details = "Loading signing certificate failed with error: " . $res;
                }
            } catch(SBException $e) {
                $error_happened = true;
                $cert = null;
                $error_details = "Loading signing certificate failed with message: " . $e->getErrorMessage();
            }
            
            if (!$error_happened and (!is_null($cert))) {
                $pdfStream = new TFileStream($filename, TFileMode::fmOpenReadWrite);
                try
                {
                    $pdfDocument = new TElPDFDocument(null);
                    $pdfDocument->Open($pdfStream);
                    
                    $publicKeyHandler = new TElPDFPublicKeySecurityHandler(null);
                    $index = $pdfDocument->AddSignature();
                    $sig = $pdfDocument->get_Signatures($index);
                    $sig->Handler = $publicKeyHandler;
                    $sig->AuthorName = "PHP PDF signer demo";
                    $sig->Reason = "Signing test";
                    
                    $dt = SBUtils\DateTimeNow();
                    $sig->SigningTime = $dt;
                    $sig->Invisible = false;
                    $sig->SignatureType = TSBPDFSignatureType::stDocument;
                    // see the full list of signature types at https://www.eldos.com/documentation/sbb/documentation/ref_cl_pdfsignature_prp_signaturetype.html
                    
                    $certStorage = new TElMemoryCertStorage(null);
                    $certStorage->Add($cert, true);
                    
                    $publicKeyHandler->CertStorage = $certStorage;
                    $publicKeyHandler->SignatureType = TSBPDFPublicKeySignatureType::pstPKCS7SHA1;
                    // see the full list of signature types at https://www.eldos.com/documentation/sbb/documentation/ref_cl_pdfpublickeysecurityhandler_prp_signaturetype.html
                    $publicKeyHandler->CustomName = "Adobe.PPKMS";
                    
                    $pdfDocument->Close(true);
                } catch(SBException $e) {
                    $error_happened = true;
                    $error_details = "PDF signing failed with message: " . $e->getErrorMessage();
                }
                $pdfStream->Free();
            }
            
            if (!$error_happened) {
                $handle = fopen($filename, "r");
                $contents = fread($handle, filesize($filename));
                fclose($handle);
                
                header('Content-Transfer-Encoding: binary');
                header('Content-length: '. strlen($contents));
                header('Content-Type: application/pdf');
                header('Content-Disposition: **inline**; filename='. $filename);
                
                print $contents;
            } else {
                print "Error happened: <br/>" . $error_details;
            }
            
            return;
        } else {
            $error_details = "";
            if (strlen($filename) == 0) {
                $error_details = $error_details . "PDF file for signing is not specified <br/>";
            }
            if (strlen($certfile) == 0) {
                $error_details = $error_details . "Signing certificate is not specified <br/>";
            }
            print "Error happened: <br/><br/>" . $error_details;
        }
    }     
?>

<html>
<head>
  <title>EldoS PDF Signer demo</title>
  <style type="text/css">
  .textheader {
    font-family: Arial;
    font-size: 16;
    font-weight: bold;
  }
  .textnormal {
    font-family: Arial;
    font-size: 12;
  }
  </style>
</head>
<body>
  <div align="center">
  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">
    <tr height="*"></tr>
    <tr height="400">
      <td width="600" valign="top">
        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">
          <tr height="50">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textheader">EldoS SecureBlackbox PDF Signer demo</div>
            </td>
          </tr>
          <tr height="70">
            <td width="100%" height="*" align="center" valign="center" class="textnormal">
              <div align="center"> This sample illustrates the use of SecureBlackbox components for signing a PDF document. <br/>
              Please select PDF document and signing certificate files and provide the certificate passphrase in the text box below, next click the 'Sign' button to sign the document. </div>
            </td>
          </tr>
          <tr height="*">
            <td width="100%" height="*">
              <form action="" method="post" enctype="multipart/form-data">
                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">
                  <tr height="30">
                    <td width="40%" align="right"> PDF file: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="filename" value="" size="30" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="40%" align="right"> Certificate file: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="certfile" value="" size="30" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="40%" align="right"> Certificate passphrase: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input width="20" type="password" name="pass" value="" size="20" /> <td>
                  </tr>
                  <tr height="45" valign="center">
                    <td colspan="3" align="center"> <input type="submit" name="sign" value="Sign"/> </td>
                  </tr>
                  <tr height="30" valign="bottom">
                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>
                  </tr>
                </table>
              </form>
            </td>
          </tr>
          <tr height="20">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>
            </td>
          </tr>
        </table>
      </td>
    </tr>
    <tr height="*"></tr>
  </table>
  </div>
</body>
</html>