<?php

error_reporting(E_ALL);
date_default_timezone_set("UTC");

if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) 
{
    print "<p style='color:red'>SecureBlackbox extension is not available, please check that you've set it up correctly</p>";
    die;
}

try {
    if (!SBUtils\GetLicense()) {
        #error Please pick the evaluation license key from <SecureBlackbox>\LicenseKey.txt file and place it in "sbb.license_key" php.ini directive or here. If the evaluation key expires, you can request an extension using the form on https://www.eldos.com/sbb/keyreq/
        SBUtils\SetLicenseKey("<enter license key here>");
    }
} catch (SBException $e) {
    print "<p style='color:red'>Setting SBB License Key failed with message: <br/>" . $e->getErrorMessage() . "</p>";
    die;
}

$GlobalLevel = 0;

function LogInfo($msg, $level)
{
        global $GlobalLevel;
        $k = $level;
        while ($k) { 
                echo "<blockquote>";
		$k--;
        }

        // ($GlobalLevel + $level) . " - " . 
 	echo "<li>" . $msg . "</li>\n";

        $k = $level;
        while ($k) { 
                echo "</blockquote>";
		$k--;
        }
}

function LogCertificateInfo($Certificate, $level)
{
	if ($Certificate != NULL)
	{
		LogInfo("Issuer: " . SBRDN\FormatRDN($Certificate->IssuerRDN), $level);
		LogInfo("Subject: " . SBRDN\FormatRDN($Certificate->SubjectRDN), $level);
		LogInfo("Serial: " . SBUtils\BinaryToString($Certificate->SerialNumber), $level);
		LogInfo("Valid From: " . $Certificate->ValidFrom->format('r'), $level);
		LogInfo("Valid To: " . $Certificate->ValidTo->format('r'), $level);
            	$M160 = $Certificate->GetHashSHA1();
		LogInfo("SHA-1 Fingerprint: " . SBUtils\DigestToStr($M160, true), $level);
	}
	else
		LogInfo("No Certificate", $level);
}

function LogCRL($CRL, $level)
{
	if ($CRL != NULL)
	{
		LogInfo("Issuer: " . SBRDN\FormatRDN($CRL->Issuer), $level);
		LogInfo("This Update: " . $CRL->ThisUpdate->format('r'), $level);
		LogInfo("Next Update: " . $CRL->NextUpdate->format('r'), $level);
	}
	else
		LogInfo("No CRL", $level);
}

function X509ValidityToString($Validity)
{
	switch ($Validity)
	{
	case TSBCertificateValidity::cvOk:
		return "OK";
	case TSBCertificateValidity::cvSelfSigned:
		return "Self-signed";
	case TSBCertificateValidity::cvInvalid:
		return "Invalid";
	case TSBCertificateValidity::cvStorageError:
		return "Storage error";
	case TSBCertificateValidity::cvChainUnvalidated:
		return "Chain unvalidated";
	default:
		return "Unknown";
	}
}

function X509ReasonToString($Reason)
{
	$s = '';
	if ((TSBCertificateValidityReason::vrBadData & $Reason) > 0)
		$s = "Bad data, ";
	if ((TSBCertificateValidityReason::vrRevoked & $Reason) > 0)
		$s .= "Revoked, ";
	if ((TSBCertificateValidityReason::vrNotYetValid & $Reason) > 0)
		$s .= "Not yet valid, ";
	if ((TSBCertificateValidityReason::vrExpired & $Reason) > 0)
		$s .= "Expired, ";
	if ((TSBCertificateValidityReason::vrInvalidSignature & $Reason) > 0)
		$s .= "Invalid signature, ";
	if ((TSBCertificateValidityReason::vrUnknownCA & $Reason) > 0)
		$s .= "Unknown CA, ";
	if ((TSBCertificateValidityReason::vrCAUnauthorized & $Reason) > 0)
		$s .= "CA Unauthorized, ";
	if ((TSBCertificateValidityReason::vrCRLNotVerified & $Reason) > 0)
		$s .= "CRL not verified, ";
	if ((TSBCertificateValidityReason::vrOCSPNotVerified & $Reason) > 0)
		$s .= "OCSP not verified, ";
	if ((TSBCertificateValidityReason::vrIdentityMismatch & $Reason) > 0)
		$s .= "Identity mismatch, ";
	if ((TSBCertificateValidityReason::vrNoKeyUsage & $Reason) > 0)
		$s .= "No key usage, ";
	if ((TSBCertificateValidityReason::vrBlocked & $Reason) > 0)
		$s .= "Blocked, ";

        if (strlen($s) > 0) {
        	$s = substr($s, 0, strlen($s) - 2);
        }
	return $s;
}

function HandleAfterCertificateValidation($Sender, $Certificate, $CACertificate, &$Validity, &$Reason, &$DoContinue)
{
        global $GlobalLevel;
	$GlobalLevel--;
	echo "</ul></li>\n";
	LogInfo("Certificate validation completed", 0);
	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	LogInfo("CA Certificate:", 1);
	LogCertificateInfo($CACertificate, 2);
	LogInfo("Validity: " . X509ValidityToString($Validity), 1);

	$s = X509ReasonToString($Reason);
	if ($s != "")
		LogInfo("Reason: " . $s, 1);
}

function HandleBeforeCertificateValidation($Sender, $Certificate)
{
        global $GlobalLevel;
	LogInfo("Starting certificate validation", 0);
	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	$GlobalLevel++;
        echo "<li><ul>\n";
}

function HandleAfterCRLUse($Sender, $Certificate, $CACertificate, $CRL)
{
	LogInfo("Successfully used CRL", 0);
	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	LogInfo("CA Certificate:", 1);
	LogCertificateInfo($CACertificate, 2);

	// log CRL
	LogInfo("CRL:", 1);
	LogCRL($CRL, 2);
}

function HandleCRLError($Sender, $Certificate, $Location, $Retriever, $ErrorCode)
{
	LogInfo("Encountered CRL error", 0);
	LogInfo("Error Code: " . $ErrorCode, 1);
	if ($Retriever != NULL)
	{
		if ($Retriever->ClassNameIs_Inst("TElHTTPCRLRetriever"))
		{
			$HTTPRetriever = $Retriever->CastTo("TElHTTPCRLRetriever");
			LogInfo("HTTP Status Code: " . $HTTPRetriever->HTTPClient->ServerStatusCode, 1);
		}

		LogInfo("Retriever: " . $Retriever->ClassName_Inst(), 1);
	}
	else
		LogInfo("Retriever: NULL", 1);

	LogInfo("Location: " . $Location, 1);	
	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
}

function HandleBeforeCRLRetrieverUse($Sender, $Certificate, $CACertificate, $NameType, $Location, &$Retriever)
{
	LogInfo("Will be retrieving CRL", 0);
	LogInfo("Location: " . $Location, 1);
	LogInfo("Name Type: " . $NameType, 1);
	if ($Retriever != NULL)
	{
		LogInfo("Retriever: " . $Retriever->ClassName_Inst(), 1);
	}
	else
		LogInfo("Retriever: NULL", 1);

	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	LogInfo("CA Certificate:", 1);
	LogCertificateInfo($CACertificate, 2);
}

function HandleCRLRetrieved($Sender, $Certificate, $CACertificate, $NameType, $Location, $CRL)
{
	LogInfo("CRL Retrieved", 0);
	LogInfo("Location: " . $Location, 1);
	LogInfo("Name Type: " . $NameType, 1);
	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	LogInfo("CA Certificate:", 1);
	LogCertificateInfo($CACertificate, 2);
	LogInfo("CRL:", 1);
	LogCRL($CRL, 2);
}

function HandleAfterOCSPResponseUse($Sender, $Certificate, $CACertificate, $Response)
{
	LogInfo("Successfully used OCSP Response", 0);
	LogInfo("Validating Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	LogInfo("CA Certificate:", 1);
	LogCertificateInfo($CACertificate, 2);

	// log OCSP
	LogInfo("OCSP Response:", 1);
	LogInfo("ResponderID: " . SBRDN\FormatRDN($Response->ResponderID->Name), 2);
	LogInfo("SHA-1 Key Hash: " . SBUtils\BinaryToString($Response->ResponderID->SHA1KeyHash), 2);
	LogInfo("Produced At: " . $Response->ProducedAt->format('r'), 2);
}

function HandleBeforeOCSPClientUse($Sender, $Certificate, $CACertificate, $OCSPLocation, &$OCSPClient)
{
	LogInfo("Will be retrieving OCSP Response", 0);
	LogInfo("Location: " . $OCSPLocation, 1);
	if ($OCSPClient != NULL)
	{
		LogInfo("OCSP Client: " . $OCSPClient->ClassName_Inst(), 1);
	}
	else
		LogInfo("OCSP Client: NULL", 1);

	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
	LogInfo("CA Certificate:", 1);
	LogCertificateInfo($CACertificate, 2);
}

function HandleOCSPError($Sender, $Certificate, $Location, $OCSPClient, $ErrorCode)
{
	LogInfo("Encountered OCSP error", 0);
	LogInfo("Error Code: " . $ErrorCode, 1);
	if ($OCSPClient != NULL)
	{
		if ($OCSPClient->ClassNameIs_Inst("TElHTTPOCSPClient") || $OCSPClient->ClassNameIs_Inst("TElHTTPOCSPIntClient"))
		{
			$httpClient = $OCSPClient->CastTo("TElHTTPOCSPClient");
			LogInfo("HTTP Status Code: " . $httpClient->HTTPClient->ServerStatusCode, 1);
		}

		LogInfo("OCSP Client: " . $OCSPClient->ClassName_Inst(), 1);
	}
	else
		LogInfo("OCSP Client: NULL", 1);

	LogInfo("Location: " . $Location, 1);
	LogInfo("Certificate:", 1);
	LogCertificateInfo($Certificate, 2);
}

function ValidateCertificate($certFilename, $password, $trustedCertsFilename, $additionalCertsFilename)
{
	try
	{
		$cert = new TElX509Certificate(NULL);
		$k = $cert->LoadFromFileAuto($certFilename, $password);
		if ($k)
		{
			echo "Failed to load certificate: " . $k . "<br/>\n";
			die;
		}

		$trustedCerts = new TElMemoryCertStorage(NULL);
		if ($trustedCertsFilename != "")
		{
			$fs = new TFileStream($trustedCertsFilename, TFileMode::fmOpenRead);
			$k = $trustedCerts->LoadFromStreamPFX($fs, "", 0);
			if ($k)
			{
				echo "Failed to load certificate storage: " . $k . "<br/>\n";
				die;
			}

			echo "Trusted certificates loaded: " . $trustedCerts->Count . "<br/>\n";
		}

		$additionalCerts = new TElMemoryCertStorage(NULL);
		if ($additionalCertsFilename != "")
		{
			$fs = new TFileStream($additionalCertsFilename, TFileMode::fmOpenRead);
			$k = $additionalCerts->LoadFromStreamPFX($fs, "", 0);
			if ($k)
			{
				echo "Failed to load certificate storage: " . $k . "<br/>\n";
				die;
			}

			echo "Additional certificates loaded: " . $additionalCerts->Count . "<br/>\n";
		}

		$validator = new TElX509CertificateValidator(NULL);

		$validator->OnAfterCertificateValidation = "HandleAfterCertificateValidation";
		$validator->OnBeforeCertificateValidation = "HandleBeforeCertificateValidation";
		$validator->OnAfterCRLUse = "HandleAfterCRLUse";
		$validator->OnCRLError = "HandleCRLError";
		$validator->OnBeforeCRLRetrieverUse = "HandleBeforeCRLRetrieverUse";
		$validator->OnCRLRetrieved = "HandleCRLRetrieved";
		$validator->OnAfterOCSPResponseUse = "HandleAfterOCSPResponseUse";
		$validator->OnBeforeOCSPClientUse = "HandleBeforeOCSPClientUse";
		$validator->OnOCSPError = "HandleOCSPError";

		$validator->CheckCRL = true;
		$validator->MandatoryCRLCheck = true;
		$validator->CheckOCSP = true;
		$validator->MandatoryOCSPCheck = true;

		$validator->AddTrustedCertificates($trustedCerts);

                $validity = TSBCertificateValidity::cvInvalid;
                $reason = 0;
                $dt = SBUtils\UtcNow();
                $CompleteChainValidation = true;
		echo "Starting validation at: " . $dt->format('r') . "\n<hr>";
                echo "<ul>";
		$validator->Validate($cert, $additionalCerts, $CompleteChainValidation, $dt, $validity, $reason);
                echo "</ul>";

		echo "<hr><p>";
		if ($validity == TSBCertificateValidity::cvOk)
			echo "Validated OK" . "<br/>\n";
		else
		{
			echo "Validity: " . X509ValidityToString($validity) . "<br/>\n";
			echo "Reason: " . X509ReasonToString($reason) . "<br/>\n";
		}

		echo "</p>";
		echo "<p>";
		echo "Used certificates: " . $validator->UsedCertificates->Count . "<br/>\n";
		echo "Used CRLs: " . $validator->UsedCRLs->Count . "<br/>\n";
		echo "Used OCSP Responses: " . $validator->UsedOCSPResponses->Count . "<br/>\n";
		echo "</p>";
	}
	catch (Exception $e)
	{
  		echo 'ERROR: ' .$e->getMessage() . "<br/>\n";
		die;
	}
}

$header = <<<EOF
<html>
<head>
  <title>EldoS PKI certificate validator demo</title>
  <style type="text/css">
  .textheader {
    font-family: Arial;
    font-size: 16;
    font-weight: bold;
  }
  .textnormal {
    font-family: Arial;
    font-size: 12;
  }
  ul li {
    display: block;
    list-style: none;
  }
  </style>
</head>
<body>
  <div align="center">
  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">
    <tr height="*"></tr>
    <tr height="400">
      <td width="600" valign="top">
EOF;

$html = <<<EOF
        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">
          <tr height="50">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textheader">EldoS SecureBlackbox PKI certificate validator</div>
            </td>
          </tr>
          <tr height="70">
            <td width="100%" height="*" align="center" valign="center" class="textnormal">
              <div align="center"> This sample illustrates the use of SecureBlackbox PKI components to validate certificates. <br/>
              Please provide the certificate to validate. </div>
            </td>
          </tr>
          <tr height="*">
            <td width="100%" height="*">            
              <form action="" method="post" enctype="multipart/form-data">
                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">
                  <tr height="30">
                    <td width="40%" align="right">Certificate file: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="certfile" value="" size="30" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="40%" align="right">Certificate passphrase: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input width="20" type="password" name="pass" value="" size="20" /> <td>
                  </tr>
                  <tr height="30">
                    <td width="40%" align="right">Additional certificates file: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="addcertsfile" value="" size="30" /> </td>
                  </tr>
                  <tr height="30">
                    <td width="40%" align="right">Trusted certificates file: </td>
                    <td width="10"></td>
                    <td width="*" align="left"> <input type="file" name="trustedcertsfile" value="" size="30" /> </td>
                  </tr>
                  <tr height="45" valign="center">
                    <td colspan="3" align="center"> <input type="submit" name="validate" value="Validate"/> </td>
                  </tr>
                  <tr height="30" valign="bottom">
                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>
                  </tr>
                </table>
              </form>
            </td>
          </tr>
          <tr height="20">
            <td width="100%" valign="center" bgcolor="#e6e6e6">
              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>
            </td>
          </tr>
        </table>
EOF;

echo $header;

if (isset($_POST["validate"]))
{
        $pass = $_POST["pass"];
        $certfile = "";
        if ($_FILES["certfile"]["error"] == 0) {
            $certfile = $_FILES["certfile"]["tmp_name"];
        }

        $addcertsfile = "";
        if ($_FILES["addcertsfile"]["error"] == 0) {
            $addcertsfile = $_FILES["addcertsfile"]["tmp_name"];
        }

        $trustedcertsfile = "";
        if ($_FILES["trustedcertsfile"]["error"] == 0) {
            $trustedcertsfile = $_FILES["trustedcertsfile"]["tmp_name"];
        }

	if ($certfile != "")
	{
		// The following lines are required for HTTP retrieval of CRLs and OCSP in TElX509CertificateValidator to work
		SBHTTPCRL\RegisterHTTPCRLRetrieverFactory();
		SBHTTPOCSPClient\RegisterHTTPOCSPClientFactory();
		SBHTTPCertRetriever\RegisterHTTPCertificateRetrieverFactory();

		ValidateCertificate($certfile, $pass, $trustedcertsfile, $addcertsfile);
	}
	else	
		echo $html;
}
else
	echo $html;

?>

      </td>
    </tr>
    <tr height="*"></tr>
  </table>
  </div>  
</body>
</html>